//*****************************************************************************
//
// hello.c - Simple hello world example.
//
// Copyright (c) 2013 Texas Instruments Incorporated.  All rights reserved.
// Software License Agreement
// 
// Texas Instruments (TI) is supplying this software for use solely and
// exclusively on TI's microcontroller products. The software is owned by
// TI and/or its suppliers, and is protected under applicable copyright
// laws. You may not combine this software with "viral" open-source
// software in order to form a larger program.
// 
// THIS SOFTWARE IS PROVIDED "AS IS" AND WITH ALL FAULTS.
// NO WARRANTIES, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT
// NOT LIMITED TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. TI SHALL NOT, UNDER ANY
// CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR CONSEQUENTIAL
// DAMAGES, FOR ANY REASON WHATSOEVER.
// 
// This is part of revision 2.0 of the DK-TM4C129X Firmware Package.
//
//*****************************************************************************

#include <stdbool.h>
#include <stdint.h>
#include <stdio.h>
#include <string.h>
#include "inc/hw_memmap.h"
#include "driverlib/sysctl.h"
#include "driverlib/gpio.h"
#include "driverlib/sysctl.h"
#include "grlib/grlib.h"
#include "drivers/frame.h"
#include "drivers/kentec320x240x16_ssd2119.h"
#include "drivers/pinout.h"
#include "macros.h"
#include "variables.h"







//*****************************************************************************
//
//! \addtogroup example_list
//! <h1>Hello World (hello)</h1>
//!
//! A very simple ``hello world'' example.  It simply displays ``Hello World!''
//! on the display and is a starting point for more complicated applications.
//! This example uses calls to the TivaWare Graphics Library graphics
//! primitives functions to update the display.  For a similar example using
//! widgets, please see ``hello_widget''.
//
//*****************************************************************************

//*****************************************************************************
//
// The error routine that is called if the driver library encounters an error.
//
//*****************************************************************************
#ifdef DEBUG
void
__error__(char *pcFilename, uint32_t ui32Line)
{
}
#endif


//*****************************************************************************
/// The array g_pucLogo contain the c array for logo "Z" at the start boot-up.
/// C-array drive generate from PPM fromat
//*****************************************************************************
const unsigned char g_pucLogo[] =
{
    IMAGE_FMT_4BPP_COMP,
    214, 0,
    214, 0,

	15,
	0x3d, 0x56, 0x00,
	0x54, 0x70, 0x00,
	0x63, 0x81, 0x00,
	0x6d, 0x85, 0x0c,
	0x74, 0x8e, 0x00,
	0x6a, 0x90, 0x01,
	0x7b, 0x97, 0x00,
	0x7a, 0xa3, 0x00,
	0x7b, 0x88, 0x4d,
	0x82, 0x9a, 0x3c,
	0x9b, 0xab, 0x68,
	0xb7, 0xc7, 0x84,
	0xd9, 0xe2, 0xab,
	0xda, 0xda, 0xcb,
	0xf5, 0xfb, 0xcd,
	0xfb, 0xff, 0xfc,
	
	0x1f, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0xa7, 0x5f, 0x17, 0x80, 0x05, 0xee,
	0xee, 0xcc, 0xba, 0x99, 0x66, 0x66, 0x00, 0x66, 0x44, 0x44, 0x7a, 0xab,
	0xcc, 0xee, 0xee, 0xff, 0x07, 0xbf, 0x77, 0x2f, 0x07, 0x07, 0x07, 0x07,
	0xc0, 0x07, 0x05, 0xfe, 0xdd, 0xba, 0x81, 0x00, 0x00, 0x00, 0x00, 0x11,
	0x12, 0x66, 0x67, 0x66, 0x44, 0x44, 0x21, 0x22, 0x11, 0xa9, 0x38, 0xab,
	0xde, 0xee, 0x07, 0xff, 0xbf, 0x77, 0x2f, 0x07, 0x07, 0x07, 0x07, 0x07,
	0x00, 0xff, 0xee, 0xcb, 0xa9, 0x31, 0x11, 0x12, 0x66, 0x00, 0x66, 0x66,
	0x77, 0x44, 0x66, 0x64, 0x55, 0x55, 0x00, 0x55, 0x46, 0x64, 0x44, 0x76,
	0x22, 0x11, 0x11, 0x07, 0x11, 0xaa, 0xbc, 0xce, 0xef, 0x02, 0xe2, 0xc6,
	0xfe, 0x87, 0x3f, 0x07, 0x07, 0x07, 0x07, 0x04, 0xee, 0x00, 0xec, 0xbb,
	0x97, 0x21, 0x11, 0x25, 0x22, 0x54, 0x04, 0x55, 0x55, 0x22, 0x22, 0x22,
	0xe9, 0x22, 0x22, 0x00, 0x66, 0x22, 0x64, 0x66, 0x46, 0x44, 0x42, 0x26,
	0x00, 0x22, 0x24, 0x9a, 0xbc, 0xce, 0xff, 0xff, 0xff, 0xff, 0xe9, 0xd4,
	0xa7, 0x5f, 0x17, 0x07, 0x07, 0x07, 0x80, 0x06, 0xee, 0xcb, 0xa9, 0x31,
	0x22, 0x24, 0x77, 0x00, 0x45, 0x55, 0x55, 0x52, 0x22, 0x33, 0x22, 0x26,
	0x00, 0x66, 0x66, 0x64, 0x66, 0x66, 0x22, 0x22, 0x22, 0x00, 0x21, 0x22,
	0x55, 0x55, 0x55, 0x75, 0x52, 0x22, 0x01, 0x27, 0x9a, 0xbc, 0xef, 0xff,
	0xff, 0xff, 0xe9, 0xff, 0xd4, 0xa7, 0x5f, 0x17, 0x07, 0x07, 0x07, 0x03,
	0x00, 0xec, 0xba, 0x93, 0x11, 0x33, 0x46, 0x22, 0x62, 0x00, 0x22, 0x22,
	0x22, 0x22, 0x77, 0xaa, 0xab, 0xbb, 0x00, 0xcc, 0xcc, 0xcc, 0xcc, 0xcc,
	0xbb, 0xbb, 0xaa, 0x40, 0x99, 0x79, 0x25, 0x55, 0x55, 0x52, 0x22, 0x22,
	0x03, 0x13, 0xab, 0xce, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0xfc, 0xa7, 0x5f,
	0x17, 0x07, 0x07, 0x07, 0xff, 0xff, 0x00, 0xfe, 0xeb, 0x93, 0x32, 0x12,
	0x26, 0x66, 0x33, 0x01, 0x33, 0x31, 0x13, 0x99, 0xab, 0xcc, 0xee, 0x3f,
	0x00, 0xff, 0xfe, 0xee, 0xec, 0xba, 0xa9, 0x63, 0x11, 0x00, 0x12, 0x66,
	0x45, 0x55, 0x22, 0x22, 0x99, 0xce, 0x7f, 0xef, 0x37, 0xbf, 0x77, 0x2f,
	0x07, 0x07, 0x07, 0x00, 0xff, 0xff, 0xfe, 0xca, 0x31, 0x12, 0x66, 0x66,
	0x01, 0x66, 0x33, 0x11, 0x18, 0x8a, 0xbe, 0xef, 0x07, 0x80, 0x07, 0xcc,
	0xa8, 0x82, 0x11, 0x22, 0x75, 0x55, 0x0f, 0x52, 0x22, 0x19, 0xbc, 0x17,
	0x07, 0x7f, 0x37, 0xe0, 0x07, 0x07, 0x07, 0xff, 0xfe, 0xc9, 0x33, 0x12,
	0x01, 0x42, 0x64, 0x62, 0x11, 0x11, 0x8a, 0xdd, 0x07, 0xc0, 0x07, 0x73,
	0xfd, 0xba, 0x31, 0x11, 0x25, 0x52, 0x07, 0x25, 0x62, 0x11, 0xac, 0xef,
	0x07, 0x07, 0x77, 0xf0, 0x2f, 0x07, 0x07, 0x05, 0xfe, 0xb8, 0x11, 0x26,
	0x03, 0x22, 0x42, 0x22, 0x13, 0x6a, 0xbc, 0x07, 0x07, 0x80, 0x77, 0xcc,
	0xa9, 0x31, 0x22, 0x66, 0x54, 0x62, 0x1f, 0x11, 0x9b, 0xef, 0x07, 0x07,
	0x77, 0x2f, 0x07, 0xc0, 0x07, 0x03, 0xfe, 0xb9, 0x10, 0x52, 0x25, 0x66,
	0x0e, 0x22, 0x39, 0xab, 0xce, 0x07, 0x07, 0x77, 0xff, 0x00, 0xff, 0xfe,
	0xcb, 0x93, 0x10, 0x22, 0x66, 0x61, 0x1f, 0x11, 0x9b, 0xef, 0x07, 0x07,
	0x77, 0x2f, 0x07, 0xc0, 0x07, 0x01, 0xec, 0xa9, 0x10, 0x13, 0x44, 0x66,
	0x0f, 0x61, 0x39, 0xbc, 0xef, 0x07, 0x07, 0x77, 0x2b, 0x00, 0xdd, 0xa8,
	0x11, 0x36, 0x66, 0x23, 0x11, 0x9b, 0x7e, 0xee, 0x07, 0x07, 0x77, 0x2f,
	0x07, 0x07, 0xff, 0x00, 0xec, 0xa9, 0x21, 0x36, 0x63, 0x62, 0x11, 0x9a,
	0x78, 0xbf, 0x07, 0x07, 0x77, 0x2e, 0xfd, 0xca, 0x30, 0x03, 0x12, 0x66,
	0x62, 0x13, 0x9b, 0xcf, 0x07, 0x07, 0xf0, 0x77, 0x2f, 0x07, 0x06, 0xfe,
	0xb9, 0x22, 0x22, 0x07, 0x66, 0x33, 0x16, 0x9b, 0xef, 0x07, 0x07, 0x77,
	0x80, 0x2f, 0xff, 0xff, 0xdb, 0x91, 0x12, 0x55, 0x62, 0x1f, 0x11, 0x9b,
	0xdf, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x80, 0x04, 0xfe, 0xb9, 0x32, 0x22,
	0x26, 0x63, 0x11, 0x3e, 0x9b, 0xee, 0x07, 0x07, 0x77, 0x2f, 0x02, 0xeb,
	0x03, 0x71, 0x22, 0x25, 0x52, 0x23, 0x8d, 0x07, 0x07, 0xf0, 0x77, 0x2f,
	0x07, 0x04, 0xd8, 0x31, 0x32, 0x44, 0x0f, 0x44, 0x11, 0x9c, 0xef, 0x07,
	0x07, 0x77, 0x2f, 0x80, 0x03, 0xfe, 0xcb, 0x52, 0x25, 0x55, 0x22, 0x01,
	0x7e, 0xae, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x02, 0xeb, 0x03, 0x31, 0x62,
	0x25, 0x24, 0x21, 0x3c, 0x07, 0x07, 0xe0, 0x77, 0x2f, 0x07, 0xeb, 0x81,
	0x36, 0x66, 0x57, 0x3f, 0x22, 0xbf, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x01,
	0x03, 0x60, 0x26, 0x25, 0x25, 0x20, 0x3c, 0x07, 0x07, 0xe0, 0x77, 0x2f,
	0x07, 0xff, 0xff, 0xeb, 0x00, 0x66, 0x1f, 0x75, 0x53, 0x1a, 0x07, 0x07,
	0x77, 0x2f, 0x07, 0x00, 0xff, 0xff, 0xb0, 0x17, 0x55, 0x22, 0x51, 0x1b,
	0xfc, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x02, 0xfa, 0x01, 0x0f, 0x27, 0x66,
	0x30, 0x3c, 0x07, 0x07, 0x77, 0x2f, 0x80, 0x06, 0xfe, 0xe8, 0x01, 0x55,
	0x75, 0x52, 0x19, 0x7e, 0xef, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x03, 0xd8,
	0x07, 0x33, 0x16, 0x96, 0x11, 0xae, 0x07, 0x07, 0x77, 0xc0, 0x2f, 0x05,
	0xeb, 0x91, 0x24, 0x75, 0x25, 0x22, 0x7e, 0xbe, 0x07, 0x07, 0x77, 0x2f,
	0x07, 0x05, 0xa8, 0x07, 0x31, 0x14, 0x72, 0x19, 0xcf, 0x07, 0x07, 0x77,
	0xc0, 0x2f, 0x03, 0xfe, 0xa1, 0x27, 0x45, 0x72, 0x62, 0x7e, 0xae, 0x07,
	0x07, 0x77, 0x2f, 0x07, 0x06, 0xfd, 0x03, 0x81, 0x72, 0x27, 0x21, 0x6b,
	0xef, 0x07, 0x07, 0xe0, 0x77, 0x2f, 0x02, 0xd9, 0x33, 0x22, 0x57, 0x13,
	0x7e, 0x8b, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x07, 0xff, 0x03, 0xfb, 0x92,
	0x25, 0x55, 0x11, 0xad, 0x07, 0x07, 0xe0, 0x77, 0x2f, 0x01, 0xec, 0x33,
	0x36, 0x44, 0x42, 0x7f, 0x18, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x07, 0x01,
	0x03, 0xc9, 0x26, 0x24, 0x61, 0x18, 0xcf, 0x07, 0x07, 0xc0, 0x77, 0x2f,
	0xff, 0xff, 0xc3, 0x16, 0x62, 0x72, 0x3f, 0x17, 0xdf, 0x07, 0x07, 0x77,
	0x2f, 0x07, 0x07, 0x81, 0x01, 0xfe, 0xb3, 0x16, 0x66, 0x63, 0x3b, 0x07,
	0xe0, 0x07, 0x77, 0x2f, 0xff, 0xfb, 0x11, 0x76, 0x77, 0x3f, 0x11, 0xac,
	0x07, 0x07, 0x77, 0x2f, 0x07, 0x07, 0x81, 0x03, 0xec, 0x92, 0x36, 0x62,
	0x22, 0xbf, 0x07, 0xe0, 0x07, 0x77, 0x2e, 0xfe, 0xa1, 0x17, 0x64, 0x20,
	0x3f, 0x3b, 0xef, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x07, 0x81, 0x04, 0xe9,
	0x13, 0x24, 0x72, 0x1b, 0xef, 0x07, 0xe0, 0x07, 0x77, 0x2d, 0xea, 0x13,
	0x72, 0x24, 0x69, 0x7f, 0xbe, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x07, 0x06,
	0x07, 0xb1, 0x24, 0x25, 0x13, 0xae, 0x07, 0x07, 0x77, 0x81, 0x2c, 0xfc,
	0x93, 0x36, 0x42, 0x71, 0x9c, 0x07, 0xfc, 0x07, 0x77, 0x2f, 0x07, 0x07,
	0x07, 0xfb, 0x31, 0x0f, 0x66, 0x63, 0x1a, 0xef, 0x07, 0x07, 0x77, 0x2b,
	0x03, 0xc9, 0x16, 0x62, 0x33, 0x19, 0xcf, 0x07, 0x07, 0xf8, 0x77, 0x2f,
	0x07, 0x07, 0x07, 0xff, 0xc8, 0x09, 0x1e, 0x24, 0x31, 0x9c, 0x07, 0x07,
	0x77, 0x2a, 0xfd, 0x07, 0x52, 0x22, 0x26, 0x61, 0xaf, 0x07, 0x07, 0x77,
	0xf0, 0x2f, 0x07, 0x07, 0x07, 0xff, 0xff, 0xfd, 0x80, 0x0f, 0x24, 0x93,
	0x1a, 0xef, 0x07, 0x07, 0x77, 0x29, 0x07, 0xd8, 0x25, 0x55, 0x71, 0x1b,
	0x07, 0x07, 0x77, 0xf8, 0x2f, 0x07, 0x07, 0x07, 0x02, 0xe8, 0x22, 0x23,
	0x38, 0x30, 0x8d, 0x07, 0x07, 0x77, 0xff, 0xff, 0xfc, 0x07, 0x92, 0x74,
	0x26, 0x10, 0xbf, 0x07, 0x07, 0x77, 0xf8, 0x2f, 0x07, 0x07, 0x07, 0x03,
	0x90, 0x36, 0x54, 0x38, 0x19, 0xef, 0x07, 0x07, 0x77, 0xff, 0xc6, 0x12,
	0x1f, 0x42, 0x61, 0x1b, 0x07, 0x07, 0x77, 0x2f, 0x07, 0xe0, 0x07, 0x07,
	0x04, 0xfa, 0x02, 0x62, 0x61, 0x9e, 0xe0, 0x07, 0x07, 0x07, 0xfe, 0x81,
	0x75, 0x69, 0x13, 0x7f, 0xcf, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x07, 0x07,
	0x87, 0x05, 0xa1, 0x64, 0x26, 0x19, 0x07, 0x07, 0x07, 0x07, 0xe9, 0x03,
	0x62, 0x71, 0x1c, 0x07, 0x07, 0x77, 0xf8, 0x2f, 0x07, 0x07, 0x07, 0x06,
	0xfa, 0x16, 0x55, 0x38, 0x21, 0xbe, 0x07, 0x07, 0x05, 0xfe, 0xa1, 0x32,
	0x1f, 0x16, 0x11, 0xbf, 0x0f, 0x07, 0x77, 0x2f, 0x07, 0xe1, 0x07, 0x07,
	0x07, 0x91, 0x25, 0x55, 0x2a, 0x07, 0xc1, 0x07, 0x05, 0xeb, 0x12, 0x96,
	0x63, 0x0c, 0x17, 0xe0, 0x07, 0x77, 0x2c, 0xee, 0xff, 0xee, 0xee, 0xee,
	0x1e, 0xee, 0xff, 0xfe, 0x07, 0x07, 0x77, 0x2b, 0xfa, 0x0e, 0x17, 0x55,
	0x22, 0xbf, 0x07, 0x07, 0x03, 0xfe, 0x0e, 0xb2, 0x16, 0x22, 0x31, 0x1f,
	0x07, 0x7f, 0xff, 0x00, 0xff, 0xfe, 0xec, 0xba, 0x99, 0x31, 0x00, 0x00,
	0x40, 0x00, 0xe9, 0x00, 0x01, 0x39, 0xaa, 0xcc, 0xef, 0xe0, 0x07, 0xbf,
	0x77, 0xff, 0xff, 0x91, 0x52, 0x72, 0x70, 0x1c, 0x07, 0x07, 0x03, 0xfc,
	0x61, 0x74, 0x26, 0x70, 0x0b, 0x27, 0x07, 0x77, 0xff, 0xec, 0xa9, 0x31,
	0x02, 0x11, 0x12, 0x22, 0x55, 0x55, 0x55, 0xe9, 0x66, 0x01, 0x22, 0x11,
	0x11, 0x11, 0x38, 0xab, 0xce, 0x07, 0xc1, 0xbf, 0x77, 0xe6, 0x27, 0x27,
	0x18, 0xef, 0x07, 0xc1, 0x07, 0x02, 0xd8, 0x12, 0x27, 0x61, 0xae, 0x2f,
	0xc0, 0x07, 0x06, 0xec, 0xba, 0x31, 0x11, 0x11, 0x26, 0x18, 0x55, 0x55,
	0x55, 0xe9, 0xd1, 0x54, 0x46, 0x66, 0x03, 0x66, 0x31, 0x00, 0x39, 0xbc,
	0xef, 0x06, 0xc6, 0x83, 0x87, 0xfe, 0x61, 0x54, 0x21, 0x9c, 0x37, 0x37,
	0x83, 0x32, 0x81, 0x27, 0x62, 0x29, 0xef, 0x2f, 0x07, 0x80, 0x04, 0xee,
	0xca, 0x93, 0x11, 0x32, 0x25, 0x46, 0x0c, 0x66, 0x55, 0x55, 0x55, 0xe9,
	0xd3, 0x44, 0x42, 0x03, 0x26, 0x66, 0x11, 0x13, 0x9b, 0xcf, 0x03, 0xdb,
	0xc3, 0xb7, 0x6c, 0xc9, 0x12, 0x42, 0x3a, 0x1f, 0x07, 0x83, 0x01, 0xeb,
	0x13, 0x37, 0x21, 0x9c, 0x37, 0x07, 0x80, 0x04, 0xed, 0xa9, 0x63, 0x11,
	0x26, 0x46, 0x64, 0x0c, 0x74, 0x44, 0x44, 0x44, 0xe9, 0xd1, 0x55, 0x55,
	0x00, 0x54, 0x44, 0x74, 0x22, 0x76, 0x66, 0x11, 0x13, 0x3e, 0x9a, 0xce,
	0x01, 0xe9, 0xd4, 0xa7, 0x59, 0xfb, 0x0c, 0x31, 0x62, 0x16, 0xcf, 0x1f,
	0x07, 0xff, 0xff, 0x1c, 0xb3, 0x36, 0x66, 0x3f, 0x07, 0x05, 0xec, 0xa8,
	0x00, 0x62, 0x22, 0x26, 0x77, 0x74, 0x65, 0x45, 0x57, 0x10, 0x44, 0x44,
	0x44, 0xe9, 0x44, 0x44, 0x55, 0x55, 0x00, 0x55, 0x54, 0x24, 0x74, 0x62,
	0x47, 0x66, 0x62, 0x03, 0x13, 0x9a, 0xcf, 0xff, 0xff, 0xff, 0xe9, 0xd4,
	0xc3, 0xa7, 0x59, 0xa3, 0x16, 0x55, 0x3c, 0x27, 0x07, 0x03, 0xff, 0xfe,
	0x93, 0x66, 0x63, 0x3b, 0x47, 0x07, 0x80, 0x03, 0xeb, 0x81, 0x13, 0x66,
	0x64, 0x46, 0x52, 0x01, 0x45, 0x44, 0x55, 0x57, 0x44, 0x44, 0x44, 0xe9,
	0x10, 0x44, 0x44, 0x54, 0xbb, 0x74, 0x46, 0x67, 0x46, 0x01, 0x67, 0x21,
	0x9a, 0xce, 0xff, 0xff, 0xff, 0xe9, 0xc0, 0xd4, 0xa7, 0xff, 0xff, 0xda,
	0x12, 0x75, 0x19, 0x60, 0xef, 0x27, 0x07, 0xf9, 0x33, 0x66, 0x31, 0xaf,
	0xe0, 0x4f, 0x07, 0x02, 0xca, 0x31, 0x33, 0x63, 0x65, 0x00, 0x55, 0x54,
	0x45, 0x45, 0x55, 0x44, 0x44, 0x44, 0xc0, 0xe9, 0xd4, 0x44, 0x44, 0x74,
	0x62, 0x74, 0x44, 0x00, 0x46, 0x26, 0x47, 0x46, 0x21, 0x3b, 0xff, 0xff,
	0x70, 0xff, 0xe9, 0xd4, 0xa7, 0xff, 0xff, 0xfd, 0x81, 0x18, 0x25, 0x61,
	0xaf, 0x27, 0x07, 0xb0, 0x62, 0x47, 0x38, 0x19, 0xef, 0x4f, 0x07, 0x01,
	0xb8, 0x11, 0x33, 0x00, 0x64, 0x47, 0x55, 0x54, 0x44, 0x47, 0x44, 0x44,
	0x58, 0x45, 0xe1, 0x44, 0xe9, 0xd3, 0x45, 0x24, 0x74, 0x00, 0x44, 0x54,
	0x64, 0x77, 0x74, 0x44, 0x26, 0x31, 0x0e, 0x8d, 0xff, 0xff, 0xff, 0xe9,
	0xd4, 0xa7, 0xff, 0x06, 0xff, 0xb6, 0x17, 0x41, 0x1c, 0x2f, 0x07, 0x03,
	0x1c, 0x66, 0x43, 0x6c, 0x57, 0x0f, 0x01, 0xd8, 0x00, 0x00, 0x33, 0x36,
	0x66, 0x64, 0x55, 0x44, 0x55, 0x45, 0x06, 0x45, 0x77, 0x44, 0x44, 0x44,
	0xe9, 0xd2, 0x66, 0x0c, 0x64, 0x44, 0x44, 0x47, 0x89, 0xc9, 0x77, 0x46,
	0x03, 0x33, 0x08, 0xdf, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0x83, 0xa7, 0xff,
	0xfa, 0x12, 0x26, 0x03, 0x37, 0x06, 0x06, 0xe3, 0x17, 0x57, 0x18, 0xdf,
	0x57, 0x0f, 0xff, 0x00, 0xee, 0xb9, 0x12, 0x76, 0x44, 0x55, 0x55, 0x55,
	0x0e, 0x44, 0x44, 0x44, 0x45, 0xe1, 0xaa, 0x91, 0x55, 0x28, 0x55, 0x66,
	0xb3, 0x54, 0x6a, 0x44, 0x64, 0x66, 0x07, 0x61, 0x6b, 0xff, 0xff, 0xff,
	0xe9, 0xd4, 0xa7, 0x03, 0xff, 0xfd, 0x80, 0x52, 0x70, 0xaf, 0x2f, 0x05,
	0x0c, 0xb1, 0x45, 0x56, 0x3a, 0x67, 0x1f, 0xff, 0xfe, 0x00, 0xc9, 0x11,
	0x66, 0x24, 0x45, 0x55, 0x55, 0x55, 0x11, 0x44, 0x44, 0x44, 0xe9, 0x44,
	0x44, 0x74, 0xbd, 0x10, 0x64, 0x44, 0x44, 0x57, 0x64, 0x67, 0x72, 0x16,
	0x0e, 0xaf, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0xa7, 0xff, 0x0c, 0xc8, 0x25,
	0x63, 0x1c, 0x37, 0x04, 0xfd, 0x33, 0x18, 0x27, 0x26, 0x9d, 0x67, 0x1f,
	0xff, 0xb8, 0x31, 0x01, 0x36, 0x62, 0x24, 0x44, 0x44, 0x44, 0x54, 0xe1,
	0x82, 0xc9, 0x44, 0x44, 0x66, 0x66, 0x66, 0xe9, 0x66, 0x50, 0x66, 0x61,
	0x45, 0x5f, 0x66, 0x46, 0x22, 0x1b, 0x1c, 0xff, 0xff, 0xff, 0xe9, 0xd4,
	    0xa7, 0xff, 0xfb, 0x0c, 0x22, 0x61, 0x13, 0xef, 0x2f, 0x03, 0xf8, 0x16,
	    0x18, 0x24, 0x51, 0xbf, 0x6f, 0x27, 0xda, 0x33, 0x16, 0x03, 0x66, 0x24,
	    0x74, 0x44, 0x44, 0x44, 0xe9, 0xd4, 0x12, 0x66, 0x66, 0x66, 0xe9, 0x66,
	    0x66, 0x63, 0x54, 0x80, 0x35, 0x47, 0x24, 0x44, 0x11, 0xbf, 0xff, 0xff,
	    0x70, 0xff, 0xe9, 0xd4, 0xa7, 0xff, 0x91, 0x66, 0x60, 0xc1, 0x37, 0x04,
	    0xc1, 0x36, 0x42, 0x6a, 0xef, 0x6f, 0x80, 0x26, 0xfb, 0x81, 0x36, 0x66,
	    0x66, 0x64, 0x44, 0x08, 0x44, 0x44, 0x44, 0x54, 0xcc, 0x44, 0x44, 0x66,
	    0x22, 0x66, 0x66, 0xe9, 0x66, 0x66, 0x44, 0x84, 0x46, 0x80, 0xdb, 0x47,
	    0x66, 0x46, 0x61, 0x3c, 0xff, 0xff, 0x70, 0xff, 0xe9, 0xd4, 0xa7, 0xff,
	    0xc3, 0x36, 0x42, 0x60, 0x1c, 0x37, 0x02, 0xfe, 0x91, 0x66, 0x51, 0x6e,
	    0xc0, 0x77, 0x2f, 0xf8, 0x03, 0x72, 0x36, 0x44, 0x42, 0x00, 0x64, 0x44,
	    0x54, 0x44, 0x44, 0x44, 0x46, 0x64, 0x82, 0xd9, 0x44, 0x44, 0x66, 0x66,
	    0x66, 0xe9, 0x66, 0x60, 0x66, 0x9b, 0x73, 0x44, 0x44, 0x74, 0x47, 0x44,
	    0x01, 0x46, 0x54, 0x18, 0xdf, 0xff, 0xff, 0xff, 0xe9, 0xc1, 0xd4, 0xa7,
	    0xfb, 0x02, 0x57, 0x1a, 0xef, 0x37, 0x83, 0x01, 0xeb, 0x32, 0x62, 0x61,
	    0xcf, 0x7f, 0x37, 0x00, 0xfd, 0x81, 0x24, 0x74, 0x62, 0x67, 0x74, 0x44,
	    0x00, 0x44, 0x57, 0x66, 0x44, 0x54, 0x66, 0x64, 0x44, 0x2e, 0x44, 0x44,
	    0xe9, 0x54, 0xd4, 0x9c, 0x6b, 0x74, 0x00, 0x44, 0x44, 0x77, 0x55, 0x61,
	    0x9f, 0xff, 0xff, 0x70, 0xff, 0xe9, 0xd4, 0xa7, 0xff, 0x16, 0x17, 0x23,
	    0x60, 0xcf, 0x37, 0x01, 0xe9, 0x22, 0x26, 0x19, 0xef, 0xc0, 0x7f, 0x37,
	    0xfe, 0x96, 0x72, 0x66, 0x67, 0x74, 0x06, 0x44, 0x44, 0x44, 0x46, 0x66,
	    0xe1, 0xc1, 0x44, 0x38, 0x44, 0x77, 0x8a, 0xb3, 0xc6, 0x44, 0x44, 0x24,
	    0x00, 0x74, 0x45, 0x54, 0x55, 0x22, 0x1b, 0xff, 0xff, 0x70, 0xff, 0xe9,
	    0xd4, 0xa7, 0xff, 0xc0, 0x55, 0x51, 0x40, 0xad, 0x37, 0xff, 0xff, 0xfe,
	    0xa1, 0x65, 0x26, 0x60, 0x1c, 0x07, 0x3f, 0xff, 0xff, 0xc2, 0x22, 0x46,
	    0x00, 0x44, 0x44, 0x47, 0x44, 0x44, 0x46, 0x66, 0x47, 0x00, 0x74, 0x44,
	    0x46, 0x46, 0x64, 0x46, 0x67, 0x44, 0x00, 0x46, 0x64, 0x66, 0x66, 0x66,
	    0x27, 0x64, 0x44, 0x28, 0x44, 0x44, 0xe9, 0x54, 0xcc, 0x44, 0x45, 0x55,
	    0x01, 0x55, 0x56, 0x13, 0xcf, 0xff, 0xff, 0xff, 0xe9, 0xc2, 0xd4, 0xa7,
	    0xf9, 0x25, 0x52, 0x1b, 0x3f, 0xff, 0x03, 0xff, 0xee, 0x91, 0x25, 0x60,
	    0xbf, 0x07, 0x3f, 0x00, 0xff, 0xff, 0xe9, 0x36, 0x44, 0x66, 0x44, 0x44,
	    0x40, 0x44, 0xe9, 0x44, 0x66, 0x77, 0x75, 0x44, 0x44, 0x02, 0x42, 0x22,
	    0x13, 0x33, 0x33, 0x33, 0xe9, 0x31, 0x00, 0x22, 0x22, 0x26, 0x66, 0x54,
	    0x44, 0x44, 0x77, 0x80, 0x14, 0x45, 0x55, 0x75, 0x56, 0x23, 0xaf, 0xff,
	    0x38, 0xff, 0xff, 0xe9, 0xd4, 0xa7, 0xfe, 0x12, 0x56, 0x20, 0x38, 0xdf,
	    0x37, 0xff, 0xeb, 0x12, 0x54, 0x13, 0xe0, 0x07, 0x4f, 0x01, 0xfb, 0x33,
	    0x47, 0x44, 0x64, 0x10, 0x44, 0x44, 0x44, 0xe9, 0x74, 0x42, 0x64, 0x62,
	    0x00, 0x22, 0x22, 0x26, 0x88, 0xaa, 0xbb, 0xbb, 0xbb, 0x08, 0xbb, 0xbb,
	    0xba, 0x99, 0x99, 0x64, 0x64, 0x44, 0x40, 0x46, 0x1b, 0x45, 0x55, 0x55,
	    0x52, 0x45, 0x62, 0x0e, 0x2c, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0xa7, 0xff,
	    0x08, 0xa2, 0x76, 0x31, 0xbe, 0x37, 0xff, 0xe8, 0x35, 0x38, 0x72, 0x1b,
	    0x07, 0x4f, 0x01, 0xfe, 0x81, 0x47, 0x00, 0x74, 0x67, 0x74, 0x44, 0x44,
	    0x66, 0x64, 0x46, 0x00, 0x64, 0x46, 0x22, 0x33, 0x69, 0xaa, 0xbc, 0xdf,
	    0x80, 0x05, 0xee, 0xcc, 0xba, 0x93, 0x32, 0x66, 0x66, 0x0c, 0x64, 0x44,
	    0x44, 0x44, 0xe9, 0xd1, 0x75, 0x24, 0x70, 0x1a, 0x2d, 0xcd, 0x96, 0xe3,
	    0x16, 0x31, 0x9e, 0x83, 0x37, 0xff, 0xb1, 0x36, 0x61, 0x9f, 0x07, 0x4f,
	    0x80, 0x02, 0xb0, 0x24, 0x46, 0x67, 0x74, 0x44, 0x44, 0x00, 0x54, 0x44,
	    0x66, 0x66, 0x21, 0x33, 0xaa, 0xbc, 0x40, 0xef, 0x07, 0xff, 0xff, 0xfe,
	    0xcb, 0xa9, 0x31, 0x08, 0x64, 0x44, 0x44, 0x44, 0xe9, 0x44, 0x44, 0x54,
	    0x0e, 0x47, 0x74, 0x24, 0x29, 0x17, 0xc6, 0x83, 0xfa, 0x10, 0x06, 0x23,
	    0x3b, 0x3f, 0xfe, 0x31, 0x36, 0x12, 0x70, 0xcf, 0x07, 0x4f, 0x02, 0xd8,
	    0x26, 0x62, 0x74, 0x00, 0x46, 0x44, 0x44, 0x44, 0x45, 0x33, 0x31, 0x39,
	    0x30, 0xac, 0xee, 0x07, 0x04, 0xec, 0xa9, 0x31, 0x26, 0xc0, 0x21, 0x09,
	    0x44, 0x44, 0x46, 0x67, 0x44, 0x61, 0x70, 0xbf, 0x07, 0xbf, 0x71, 0xfd,
	    0x81, 0x66, 0x29, 0x43, 0xef, 0x36, 0xeb, 0x03, 0x26, 0x1a, 0x07, 0xbf,
	    0x80, 0x13, 0xfd, 0x22, 0x26, 0x66, 0x45, 0x55, 0x55, 0x06, 0x47, 0x55,
	    0x31, 0x19, 0xbe, 0x07, 0x07, 0xfc, 0x04, 0xa1, 0x16, 0x44, 0x44, 0x44,
	    0xe9, 0x44, 0x44, 0x07, 0x66, 0x44, 0x45, 0x61, 0xae, 0x07, 0xbf, 0x72,
	    0x08, 0xb1, 0x64, 0x22, 0xcf, 0x36, 0xe8, 0x09, 0x31, 0x38, 0x3b, 0xef,
	    0x07, 0xbf, 0x0a, 0xfd, 0x22, 0x67, 0x00, 0x46, 0x45, 0x55, 0x55, 0x55,
	    0x22, 0x19, 0xce, 0xc0, 0x07, 0x07, 0xff, 0xff, 0xeb, 0x90, 0x44, 0x44,
	    0x40, 0x44, 0xe9, 0x44, 0x44, 0x64, 0x72, 0x57, 0x21, 0x70, 0x8d, 0x07,
	    0xbf, 0x72, 0xd3, 0x14, 0x41, 0xaf, 0x87, 0x36, 0xc0, 0x26, 0x60, 0xae,
	    0x07, 0xbf, 0x14, 0x00, 0xa0, 0x37, 0x55, 0x57, 0x55, 0x46, 0x30, 0x18,
	    0x70, 0xce, 0x07, 0x07, 0x02, 0xd8, 0x03, 0x64, 0x25, 0x00, 0x74, 0x44,
	    0x44, 0x45, 0x55, 0x44, 0x44, 0x44, 0x38, 0x63, 0x3c, 0x07, 0x07, 0x72,
	    0xfa, 0x25, 0x52, 0x41, 0x1e, 0x35, 0xfe, 0x91, 0x46, 0x33, 0xcf, 0x07,
	    0xc0, 0xbf, 0x14, 0xe1, 0x17, 0x45, 0x75, 0x54, 0x61, 0x38, 0x38, 0xdf,
	    0x07, 0x07, 0x03, 0xfd, 0x91, 0x26, 0x00, 0x67, 0x57, 0x44, 0x44, 0x45,
	    0x55, 0x44, 0x44, 0x1c, 0x44, 0x62, 0x3b, 0x07, 0x07, 0x72, 0xfc, 0x62,
	    0x11, 0x56, 0x1a, 0xef, 0xad, 0x33, 0x46, 0x19, 0xad, 0xc0, 0x07, 0x8f,
	    0xfa, 0x11, 0x67, 0x55, 0x72, 0x19, 0x70, 0xbe, 0x0f, 0x07, 0x05, 0xc6,
	    0x14, 0x77, 0x54, 0x00, 0x44, 0x44, 0x45, 0x55, 0x44, 0x44, 0x54, 0x62,
	    0x38, 0x1a, 0xef, 0x07, 0x07, 0x71, 0xfe, 0xa2, 0x46, 0x43, 0x23, 0x35,
	    0xfa, 0x32, 0x62, 0x3b, 0x07, 0xbf, 0x81, 0x75, 0xfb, 0x33, 0x32, 0x66,
	    0x13, 0xae, 0x0f, 0xc0, 0x07, 0x07, 0x12, 0x72, 0x74, 0x44, 0x44, 0x45,
	    0x01, 0x55, 0x44, 0x45, 0x54, 0x46, 0x3a, 0xef, 0x07, 0xc2, 0x07, 0x72,
	    0xb2, 0x62, 0x31, 0xbe, 0x34, 0xe9, 0x1c, 0x32, 0x71, 0x9e, 0x07, 0x07,
	    0x76, 0xa1, 0x29, 0x38, 0x31, 0x9c, 0x17, 0x07, 0x07, 0xfe, 0x91, 0x46,
	    0x00, 0x44, 0x44, 0x44, 0x45, 0x55, 0x64, 0x45, 0x55, 0x1c, 0x56, 0x2a,
	    0xef, 0x07, 0x07, 0x72, 0xe9, 0x12, 0x21, 0x63, 0x9e, 0x34, 0xb3, 0x26,
	    0x41, 0xaf, 0x07, 0xc7, 0x07, 0x76, 0xb3, 0x30, 0x1b, 0x1f, 0x07, 0x07,
	    0x00, 0xff, 0xff, 0xb1, 0x17, 0x27, 0x44, 0x44, 0x45, 0x47, 0x55, 0xe9,
	    0x55, 0x29, 0xef, 0x07, 0x07, 0x72, 0x08, 0xfb, 0x12, 0x33, 0x1e, 0x33,
	    0xfe, 0x93, 0x24, 0x38, 0x63, 0xbf, 0x07, 0x07, 0x76, 0xf8, 0x08, 0xcf,
	    0xe0, 0x1f, 0x07, 0x07, 0xff, 0xff, 0xe3, 0x17, 0x27, 0x00, 0x44, 0x44,
	    0x45, 0x55, 0x64, 0x45, 0x55, 0x55, 0x38, 0x29, 0xef, 0x07, 0x07, 0x72,
	    0xfc, 0x33, 0x26, 0x43, 0x0a, 0xbc, 0x32, 0x54, 0x29, 0xef, 0x07, 0x07,
	    0x9e, 0x76, 0xfb, 0xbd, 0x27, 0x07, 0x07, 0x01, 0xfa, 0x00, 0x16, 0x66,
	    0x44, 0x44, 0x44, 0x55, 0x64, 0x45, 0x0e, 0x55, 0x55, 0x29, 0xef, 0x07,
	    0x07, 0x73, 0x93, 0x21, 0x27, 0x24, 0x33, 0xfb, 0x34, 0x42, 0x2b, 0x07,
	    0xfc, 0x07, 0x77, 0x2f, 0x07, 0x07, 0x03, 0xfb, 0x31, 0x00, 0x46, 0x44,
	    0x44, 0x44, 0x55, 0x46, 0x64, 0x55, 0x1c, 0x55, 0x2a, 0xef, 0x07, 0x07,
	    0x73, 0xb3, 0x32, 0x21, 0x72, 0xdf, 0x2a, 0xea, 0x26, 0x52, 0x9c, 0x07,
	    0xfc, 0x07, 0x77, 0x2f, 0x07, 0x07, 0x03, 0xfb, 0x33, 0x00, 0x46, 0x44,
	    0x44, 0x44, 0x55, 0x46, 0x44, 0x55, 0x1c, 0x55, 0x2a, 0xef, 0x07, 0x07,
	    0x73, 0xc8, 0x32, 0x21, 0x62, 0xbe, 0x2a, 0xc9, 0x26, 0x42, 0xae, 0x07,
	    0xfc, 0x07, 0x77, 0x2f, 0x07, 0x07, 0x03, 0xfc, 0x33, 0x00, 0x44, 0x44,
	    0x44, 0x44, 0x55, 0x44, 0x44, 0x57, 0x1c, 0x42, 0x3a, 0xef, 0x07, 0x07,
	    0x73, 0xea, 0x32, 0x20, 0x62, 0x8e, 0x29, 0xfe, 0xb3, 0x26, 0x23, 0xbf,
	    0xfe, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x07, 0x03, 0xfc, 0x00, 0x33, 0x44,
	    0x44, 0x44, 0x44, 0x55, 0x47, 0x74, 0x1c, 0x57, 0x42, 0x3b, 0x07, 0x07,
	    0x74, 0xfb, 0x32, 0x20, 0x62, 0x3c, 0x21, 0xfe, 0xa1, 0x66, 0x26, 0xcf,
	    0xfe, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x07, 0x03, 0xfc, 0x00, 0x33, 0x44,
	    0x44, 0x44, 0x44, 0x55, 0x47, 0x74, 0x1c, 0x44, 0x63, 0x3c, 0x07, 0x07,
	    0x74, 0xfc, 0x33, 0x11, 0x62, 0x1b, 0xef, 0xc9, 0x91, 0x67, 0x1a, 0xc9,
	    0xfe, 0x07, 0xaf, 0x67, 0x1f, 0x07, 0x07, 0x01, 0xfb, 0x00, 0x37, 0x54,
	    0x44, 0x44, 0x44, 0x55, 0x47, 0x44, 0x1c, 0x45, 0x63, 0x8e, 0x07, 0x07,
	    0x74, 0xfe, 0xa1, 0x00, 0x26, 0x19, 0xef, 0xff, 0xff, 0xec, 0x32, 0x62,
	    0x7c, 0x1b, 0x07, 0x07, 0x77, 0x2f, 0x04, 0xfe, 0xcc, 0x02, 0xcb, 0xbb,
	    0xbb, 0xbb, 0xbc, 0xde, 0x07, 0xff, 0x00, 0xfa, 0x36, 0x45, 0x44, 0x44,
	    0x44, 0x55, 0x44, 0x0e, 0x44, 0x47, 0x32, 0xbf, 0x57, 0x0f, 0x75, 0xb1,
	    0x00, 0x24, 0x23, 0xcf, 0xff, 0xff, 0xeb, 0x12, 0x22, 0x7c, 0x1c, 0x07,
	    0x07, 0x77, 0x2f, 0x03, 0xfc, 0xba, 0x00, 0x88, 0x33, 0x11, 0x11, 0x13,
	    0x33, 0x88, 0xaa, 0x40, 0xdd, 0x06, 0xf8, 0x32, 0x44, 0x44, 0x44, 0x44,
	    0x03, 0x55, 0x74, 0x47, 0x46, 0x23, 0xcf, 0x66, 0x26, 0x88, 0x87, 0xc1,
	    0x24, 0x33, 0x19, 0xea, 0x25, 0x61, 0x7c, 0x8f, 0x07, 0x07, 0x77, 0x2f,
	    0x02, 0xeb, 0x93, 0x00, 0x31, 0x12, 0x26, 0x55, 0x55, 0x55, 0x22, 0x21,
	    0x08, 0x33, 0x29, 0x9a, 0xce, 0x04, 0xc3, 0x34, 0x44, 0x00, 0x46, 0x66,
	    0x66, 0x64, 0x55, 0x72, 0x63, 0x38, 0xf0, 0x7c, 0x4c, 0xa7, 0x5b, 0xf8,
	    0x16, 0x52, 0xae, 0x03, 0xff, 0xff, 0xe9, 0x25, 0x61, 0xaf, 0x07, 0x07,
	    0xe0, 0x77, 0x2f, 0x01, 0xeb, 0x91, 0x13, 0x32, 0x44, 0x00, 0x45, 0x55,
	    0x55, 0x55, 0x56, 0x66, 0x66, 0x12, 0x10, 0x13, 0x39, 0xbe, 0x03, 0xa3,
	    0x44, 0x47, 0x46, 0x01, 0x66, 0x66, 0x44, 0x57, 0x54, 0x22, 0x1d, 0x83,
	    0xe0, 0x5b, 0xb7, 0x6d, 0xfa, 0x13, 0x52, 0x9e, 0xff, 0x07, 0xff, 0xc6,
	    0x22, 0x21, 0xbf, 0x07, 0x07, 0x77, 0x80, 0x2f, 0xff, 0xff, 0xeb, 0x96,
	    0x33, 0x26, 0x23, 0x00, 0x75, 0x55, 0x55, 0x55, 0x55, 0x55, 0x44, 0x66,
	    0x04, 0x56, 0x62, 0x11, 0x18, 0xbd, 0x01, 0xfe, 0x31, 0x00, 0x47, 0x44,
	    0x46, 0x66, 0x64, 0x44, 0x57, 0x52, 0x3e, 0x61, 0xaf, 0x89, 0x71, 0xd4,
	    0xa7, 0x5b, 0xfb, 0x00, 0x13, 0x52, 0x6c, 0xff, 0xff, 0xb1, 0x55, 0x23,
	    0x78, 0xef, 0x07, 0x07, 0x77, 0x2f, 0xff, 0xfe, 0xa3, 0x01, 0x12, 0x47,
	    0x44, 0x44, 0x55, 0x55, 0x55, 0xe9, 0x00, 0x55, 0x55, 0x52, 0x24, 0x66,
	    0x33, 0x38, 0xac, 0x00, 0xff, 0xff, 0xfb, 0x13, 0x47, 0x44, 0x46, 0x66,
	    0x81, 0x41, 0x52, 0x33, 0xef, 0xff, 0xff, 0xff, 0xe9, 0xe0, 0xd4, 0xa7,
	    0x5b, 0xfe, 0x33, 0x52, 0x2c, 0xff, 0x0f, 0xff, 0xa1, 0x75, 0x29, 0x07,
	    0x07, 0x77, 0x2f, 0x00, 0xff, 0xff, 0xc9, 0x12, 0x44, 0x55, 0x55, 0x57,
	    0x10, 0x55, 0x55, 0x55, 0xe9, 0x55, 0x55, 0x77, 0x76, 0x00, 0x26, 0x66,
	    0x33, 0x13, 0xac, 0xef, 0xc9, 0x32, 0x00, 0x44, 0x44, 0x46, 0x64, 0x44,
	    0x45, 0x52, 0x73, 0x07, 0x0c, 0xef, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0xa7,
	    0x80, 0x5c, 0x91, 0x52, 0x1b, 0xef, 0xfe, 0x91, 0x72, 0x78, 0x1a, 0x07,
	    0x07, 0x77, 0x2f, 0xff, 0xfe, 0x91, 0x04, 0x14, 0x45, 0x55, 0x55, 0x55,
	    0xe9, 0x55, 0x25, 0x80, 0xc2, 0x75, 0x47, 0x46, 0x46, 0x31, 0x16, 0xbe,
	    0x00, 0xa1, 0x66, 0x64, 0x44, 0x44, 0x44, 0x45, 0x55, 0x03, 0x42, 0x11,
	    0xaf, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0xc0, 0xa7, 0x5d, 0xa1, 0x52, 0x1a,
	    0xef, 0xfd, 0x32, 0x3c, 0x52, 0x1b, 0x07, 0x07, 0x77, 0x2f, 0xff, 0xea,
	    0x00, 0x11, 0x66, 0x45, 0x75, 0x55, 0x57, 0x52, 0x22, 0x00, 0x26, 0x22,
	    0x22, 0x25, 0x55, 0x55, 0x77, 0x55, 0x00, 0x77, 0x46, 0x64, 0x47, 0x61,
	    0x29, 0x72, 0x66, 0x00, 0x64, 0x44, 0x44, 0x45, 0x45, 0x55, 0x63, 0x19,
	    0x0f, 0xef, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0xa7, 0x5d, 0x00, 0xb1, 0x55,
	    0x29, 0xef, 0xfd, 0x12, 0x52, 0x3c, 0xf0, 0x07, 0x07, 0x77, 0x2f, 0xff,
	    0xb3, 0x16, 0x44, 0x00, 0x45, 0x54, 0x54, 0x45, 0x22, 0x13, 0x33, 0x38,
	    0x00, 0x33, 0x31, 0x22, 0x55, 0x55, 0x55, 0x44, 0x47, 0x00, 0x44, 0x62,
	    0x64, 0x76, 0x27, 0x55, 0x67, 0x64, 0x00, 0x44, 0x44, 0x45, 0x55, 0x31,
	    0x9c, 0xff, 0xff, 0x78, 0xff, 0xe9, 0xd4, 0xa7, 0x5e, 0xc1, 0x55, 0x23,
	    0x07, 0xef, 0xfb, 0x16, 0x52, 0x9e, 0x07, 0x07, 0x77, 0x80, 0x2f, 0xfe,
	    0xa1, 0x36, 0x44, 0x64, 0x46, 0x44, 0x00, 0x41, 0x19, 0xac, 0xcc, 0xde,
	    0xec, 0xba, 0x91, 0x00, 0x12, 0x72, 0x57, 0x44, 0x45, 0x44, 0x44, 0x44,
	    0x10, 0x67, 0x55, 0x55, 0xd1, 0x72, 0x75, 0x52, 0x08, 0x0f, 0xcf, 0xff,
	    0xff, 0xff, 0xe9, 0xd4, 0xa7, 0x5e, 0x00, 0xe8, 0x55, 0x21, 0xcf, 0xfa,
	    0x16, 0x52, 0x9e, 0xf0, 0x07, 0x07, 0x77, 0x2f, 0xfc, 0x91, 0x37, 0x66,
	    0x01, 0x76, 0x64, 0x61, 0x19, 0xbe, 0xee, 0xef, 0x01, 0x00, 0xec, 0x91,
	    0x14, 0x74, 0x66, 0x46, 0x44, 0x44, 0x00, 0x64, 0x76, 0x54, 0x55, 0x44,
	    0x44, 0x46, 0x64, 0x1f, 0x42, 0x61, 0xac, 0x51, 0x39, 0xd4, 0xa7, 0x5f,
	    0x00, 0xe8, 0x25, 0x21, 0xbf, 0xf8, 0x14, 0x52, 0xaf, 0xf0, 0x07, 0x07,
	    0x77, 0x2f, 0xeb, 0x31, 0x66, 0x64, 0x08, 0x76, 0x66, 0x31, 0x9c, 0x05,
	    0xfc, 0x33, 0x13, 0x00, 0x46, 0x64, 0x44, 0x46, 0x44, 0x44, 0x55, 0x55,
	    0x01, 0x44, 0x46, 0x52, 0x74, 0x23, 0x19, 0xdf, 0x3d, 0xe0, 0x05, 0x97,
	    0x4d, 0xfa, 0x25, 0x61, 0xaf, 0xf3, 0x1e, 0x16, 0x52, 0xbf, 0x07, 0x07,
	    0x77, 0x2f, 0xfa, 0x01, 0x12, 0x66, 0x44, 0x44, 0x46, 0x23, 0xce, 0x06,
	    0x00, 0xe9, 0x13, 0x16, 0x72, 0x44, 0x44, 0x44, 0x44, 0x00, 0x55, 0x54,
	    0x44, 0x46, 0x44, 0x26, 0x30, 0xaf, 0xf0, 0x46, 0x06, 0x87, 0x3c, 0xfb,
	    0x25, 0x61, 0x9e, 0x0f, 0xe1, 0x24, 0x52, 0xcf, 0x07, 0x07, 0x77, 0x2f,
	    0x00, 0xfa, 0x12, 0x76, 0x44, 0x47, 0x42, 0x66, 0xee, 0x80, 0x06, 0xfe,
	    0xa1, 0x36, 0x34, 0x44, 0x44, 0x44, 0x00, 0x44, 0x55, 0x54, 0x44, 0x76,
	    0x42, 0x70, 0x1c, 0xf0, 0x4e, 0x0e, 0x87, 0x3d, 0xfd, 0x25, 0x61, 0x3e,
	    0x0f, 0xe0, 0x64, 0x22, 0xcf, 0x07, 0x07, 0x77, 0x2f, 0x00, 0xfa, 0x12,
	    0x46, 0x44, 0x54, 0x45, 0x21, 0xee, 0x80, 0x07, 0xeb, 0x33, 0x76, 0x44,
	    0x44, 0x55, 0x44, 0x03, 0x55, 0x54, 0x44, 0x66, 0x47, 0x19, 0x57, 0x0f,
	    0xc0, 0x77, 0x2c, 0xfd, 0x26, 0x23, 0x1e, 0xe0, 0x64, 0x3c, 0x26, 0xef,
	    0x07, 0x07, 0x77, 0x2f, 0xfb, 0x33, 0x02, 0x44, 0x75, 0x55, 0x55, 0x21,
	    0xae, 0x07, 0xfc, 0x00, 0x93, 0x64, 0x44, 0x45, 0x55, 0x55, 0x55, 0x54,
	    0x1e, 0x46, 0x44, 0x41, 0x57, 0x17, 0x7f, 0x35, 0xfd, 0x01, 0x62, 0x23,
	    0x0e, 0xe0, 0x24, 0x29, 0xef, 0x07, 0xe0, 0x07, 0x77, 0x2f, 0xfb, 0x31,
	    0x47, 0x75, 0x77, 0x10, 0x55, 0x52, 0x1a, 0x06, 0xed, 0xba, 0x96, 0x64,
	    0x00, 0x54, 0x55, 0x55, 0x55, 0x55, 0x54, 0x66, 0x44, 0x3c, 0x64, 0x6b,
	    0x56, 0x16, 0x87, 0x3e, 0xfd, 0x62, 0x07, 0x33, 0x0e, 0xc0, 0x62, 0x1a,
	    0x07, 0x07, 0x77, 0x80, 0x2f, 0xff, 0xfc, 0x93, 0x64, 0x55, 0x57, 0x75,
	    0x00, 0x45, 0x63, 0x9a, 0xce, 0xee, 0xff, 0xfe, 0xee, 0x00, 0xee, 0xcb,
	    0xa3, 0x11, 0x36, 0x67, 0x45, 0x55, 0x00, 0x55, 0x55, 0x44, 0x44, 0x55,
	    0x44, 0x76, 0x33, 0x0f, 0xae, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0xa7, 0x5f,
	    0x81, 0x11, 0x91, 0x36, 0x0e, 0xc0, 0x62, 0x3a, 0x07, 0xe0, 0x07, 0x77,
	    0x2f, 0xff, 0xff, 0xb1, 0x17, 0x77, 0x00, 0x55, 0x55, 0x44, 0x66, 0x12,
	    0x99, 0xab, 0xbb, 0x00, 0xbb, 0xba, 0xa9, 0x62, 0x13, 0x23, 0x36, 0x46,
	    0x28, 0x55, 0x55, 0x71, 0x44, 0x59, 0x61, 0x3b, 0xdf, 0x1e, 0xff, 0xff,
	    0xff, 0xe9, 0xd4, 0xa7, 0x5f, 0xff, 0x01, 0xff, 0xa1, 0x36, 0x0e, 0xb0,
	    0x42, 0x3b, 0x07, 0xe0, 0x07, 0x77, 0x2f, 0xff, 0xff, 0xda, 0x31, 0x22,
	    0x00, 0x57, 0x75, 0x24, 0x42, 0x62, 0x22, 0x33, 0x23, 0x00, 0x33, 0x33,
	    0x22, 0x22, 0x76, 0x66, 0x44, 0x66, 0x00, 0x47, 0x77, 0x55, 0x55, 0x44,
	    0x54, 0x45, 0x54, 0x01, 0x42, 0x63, 0x13, 0xaf, 0xff, 0xff, 0xff, 0xe9,
	    0xe0, 0xd4, 0xa7, 0x5f, 0xff, 0xff, 0xa2, 0x36, 0x0c, 0x1e, 0xa1, 0x72,
	    0x2b, 0x07, 0x07, 0x77, 0x2f, 0xff, 0x00, 0xff, 0xfd, 0x81, 0x67, 0x72,
	    0x24, 0x74, 0x24, 0x00, 0x55, 0x55, 0x25, 0x22, 0x22, 0x22, 0x25, 0x57,
	    0x00, 0x62, 0x47, 0x42, 0x27, 0x62, 0x24, 0x55, 0x75, 0x00, 0x64, 0x44,
	    0x45, 0x54, 0x72, 0x69, 0x31, 0x3b, 0x1e, 0xff, 0xff, 0xff, 0xe9, 0xd4,
	    0xa7, 0x5f, 0xff, 0x01, 0xff, 0xa2, 0x36, 0x0c, 0x91, 0x72, 0x2b, 0x07,
	    0xf0, 0x07, 0x77, 0x2f, 0x01, 0xd8, 0x01, 0x67, 0x75, 0x00, 0x66, 0x44,
	    0x55, 0x55, 0x55, 0x54, 0x77, 0x45, 0x00, 0x55, 0x55, 0x57, 0x42, 0x54,
	    0x46, 0x64, 0x44, 0x00, 0x55, 0x75, 0x64, 0x44, 0x45, 0x55, 0x57, 0x46,
	    0x03, 0x36, 0x33, 0xce, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0xc0, 0xa7, 0x5f,
	    0xff, 0xb2, 0x26, 0x0b, 0x92, 0x52, 0x7c, 0x2b, 0x07, 0x07, 0x77, 0x2f,
	    0x01, 0xfe, 0xa0, 0x00, 0x03, 0x66, 0x25, 0x55, 0x75, 0x55, 0x55, 0x55,
	    0x80, 0xe9, 0x47, 0x55, 0x54, 0x62, 0x10, 0x01, 0x24, 0x00, 0x75, 0x55,
	    0x67, 0x44, 0x45, 0x55, 0x54, 0x42, 0x03, 0x69, 0x61, 0x6b, 0xff, 0xff,
	    0xff, 0xe9, 0xd4, 0xc0, 0xa7, 0x5f, 0xff, 0xb2, 0x26, 0x1b, 0x62, 0x42,
	    0x7c, 0x6c, 0x07, 0x07, 0x77, 0x2f, 0x02, 0xfe, 0x80, 0x00, 0x03, 0x74,
	    0x24, 0x75, 0x55, 0x57, 0x55, 0x55, 0x00, 0x66, 0x66, 0x66, 0x52, 0x21,
	    0x01, 0x9b, 0xec, 0x00, 0x31, 0x47, 0x75, 0x66, 0x44, 0x45, 0x55, 0x75,
	    0x00, 0x44, 0x47, 0x44, 0x17, 0xcf, 0xff, 0xff, 0xff, 0xf0, 0xe9, 0xd4,
	    0xa7, 0x5f, 0xb2, 0x26, 0x1a, 0x62, 0x3e, 0x42, 0x4c, 0x07, 0x07, 0x77,
	    0x2f, 0x03, 0xfc, 0x00, 0xa3, 0x01, 0x22, 0x22, 0x46, 0x22, 0x64, 0x44,
	    0x00, 0x62, 0x33, 0x11, 0x22, 0x9a, 0xbe, 0xff, 0xfe, 0x00, 0x93, 0x42,
	    0x57, 0x66, 0x44, 0x44, 0x55, 0x55, 0x00, 0x75, 0x46, 0x44, 0x51, 0x9e,
	    0xff, 0xff, 0xff, 0xf0, 0xe9, 0xd4, 0xa7, 0x5f, 0xb2, 0x26, 0x1a, 0x66,
	    0x3e, 0x42, 0x6c, 0x07, 0x07, 0x77, 0x2f, 0x04, 0xfe, 0x00, 0xba, 0x31,
	    0x33, 0x11, 0x11, 0x11, 0x11, 0x11, 0x10, 0x38, 0xab, 0xce, 0x02, 0xb1,
	    0x26, 0x45, 0x44, 0x00, 0x44, 0x44, 0x55, 0x55, 0x55, 0x44, 0x44, 0x72,
	    0x39, 0x19, 0xef, 0x72, 0x52, 0x31, 0xee, 0xec, 0x9f, 0x81, 0x55, 0xb2,
	    0x24, 0x29, 0x66, 0x42, 0x6c, 0x57, 0xf0, 0x0f, 0x77, 0x2f, 0x07, 0xbb,
	    0xba, 0xaa, 0xaa, 0x20, 0xab, 0xce, 0x05, 0xe9, 0x16, 0x42, 0x44, 0x44,
	    0x00, 0x54, 0x45, 0x55, 0x55, 0x55, 0x44, 0x75, 0x23, 0x40, 0xae, 0x03,
	    0xee, 0xec, 0xcc, 0xbb, 0xbb, 0xaa, 0x1c, 0x99, 0x31, 0x8f, 0x93, 0x6b,
	    0x43, 0xb2, 0x24, 0x0f, 0x29, 0x46, 0x52, 0x6c, 0x5f, 0x17, 0x77, 0x2f,
	    0xe0, 0x07, 0x07, 0x02, 0xfb, 0x16, 0x74, 0x44, 0x44, 0x00, 0x44, 0x44,
	    0x45, 0x55, 0x55, 0x55, 0x55, 0x52, 0x00, 0x3b, 0xfe, 0xec, 0xcc, 0xbb,
	    0xaa, 0x99, 0x93, 0x01, 0x33, 0x31, 0x00, 0x01, 0x13, 0x33, 0x0e, 0x02,
	    0xc0, 0xe2, 0xc5, 0xb2, 0x24, 0x27, 0x46, 0x52, 0x6c, 0xfe, 0x5f, 0x17,
	    0x77, 0x2f, 0x07, 0x07, 0x02, 0xfc, 0x04, 0x32, 0x66, 0x44, 0x44, 0x44,
	    0xe9, 0x44, 0x44, 0x00, 0x55, 0x76, 0x19, 0xa9, 0x96, 0x63, 0x31, 0x11,
	    0x00, 0x11, 0x22, 0x22, 0x22, 0x77, 0x74, 0x44, 0x46, 0x70, 0x1a, 0x02,
	    0xe2, 0xc5, 0xb2, 0x24, 0x27, 0x66, 0x3f, 0x55, 0x4c, 0x5f, 0x17, 0x77,
	    0x2f, 0x07, 0x07, 0x81, 0x02, 0xfe, 0x91, 0x27, 0x44, 0x44, 0x44, 0xe9,
	    0x00, 0x44, 0x44, 0x54, 0x44, 0x63, 0x13, 0x22, 0x22, 0x00, 0x66, 0x76,
	    0x66, 0x66, 0x66, 0x66, 0x66, 0x62, 0x0e, 0x66, 0x44, 0x31, 0xef, 0x01,
	    0xe9, 0xd4, 0xff, 0x01, 0xff, 0xb6, 0x24, 0x2a, 0x64, 0x55, 0x4c, 0x67,
	    0xfc, 0x1f, 0x77, 0x2f, 0x07, 0x07, 0x02, 0xef, 0xc6, 0x04, 0x26, 0x44,
	    0x44, 0x44, 0x45, 0xe9, 0x44, 0x47, 0x00, 0x66, 0x46, 0x64, 0x44, 0x44,
	    0x66, 0x64, 0x74, 0xc7, 0x79, 0x61, 0x44, 0x21, 0xbf, 0x01, 0xe9, 0xd4,
	    0x00, 0xff, 0xff, 0xb4, 0x26, 0x29, 0x44, 0x52, 0x4c, 0xfe, 0x67, 0x1f,
	    0x77, 0x2f, 0x07, 0x07, 0x02, 0xfe, 0x02, 0xc9, 0x62, 0x74, 0x44, 0x44,
	    0x44, 0xe9, 0x44, 0x00, 0x47, 0x63, 0x66, 0x64, 0x77, 0x77, 0x74, 0x44,
	    0x00, 0x55, 0x55, 0x55, 0x54, 0x44, 0x44, 0x45, 0x45, 0x38, 0x62, 0x9e,
	    0x01, 0xe9, 0xd4, 0xff, 0xff, 0xb2, 0x07, 0x26, 0x2a, 0x44, 0x55, 0x6c,
	    0x67, 0x1f, 0x77, 0xe0, 0x2f, 0x07, 0x07, 0xff, 0xff, 0xfe, 0xcb, 0x91,
	    0x00, 0x11, 0x24, 0x77, 0x44, 0x44, 0x44, 0x46, 0x66, 0x00, 0x64, 0x44,
	    0x46, 0x44, 0x64, 0x44, 0x77, 0x77, 0x04, 0x77, 0x44, 0x55, 0x55, 0x55,
	    0xe9, 0x47, 0x45, 0x06, 0x72, 0x1b, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0xff,
	    0x01, 0xff, 0xb2, 0x26, 0x2a, 0x72, 0x42, 0x6b, 0x67, 0xf8, 0x1f, 0x77,
	    0x2f, 0x07, 0x06, 0xec, 0xbb, 0xa9, 0x00, 0x10, 0x11, 0x12, 0x66, 0x66,
	    0x44, 0x44, 0x44, 0xf0, 0xe9, 0xd4, 0xa7, 0x59, 0x39, 0x18, 0xff, 0xff,
	    0x60, 0xff, 0xe9, 0xd4, 0xff, 0xff, 0xb3, 0x33, 0x1b, 0x1f, 0xa2, 0x42,
	    0x2b, 0x67, 0x1f, 0x77, 0x2f, 0x07, 0x80, 0x03, 0xed, 0xcb, 0xaa, 0x93,
	    0x11, 0x11, 0x22, 0x01, 0x65, 0x55, 0x55, 0x55, 0x44, 0x44, 0x44, 0xe9,
	    0xe0, 0xd4, 0xa7, 0x59, 0x63, 0x13, 0xbf, 0xff, 0xff, 0x60, 0xff, 0xe9,
	    0xd4, 0xff, 0xb3, 0x33, 0x1b, 0xa1, 0x3e, 0x42, 0x2b, 0x6f, 0x27, 0x77,
	    0x2f, 0x07, 0xff, 0x00, 0xff, 0xfe, 0xcc, 0xba, 0xa9, 0x33, 0x11, 0x32,
	    0x00, 0x26, 0x55, 0x55, 0x77, 0x55, 0x55, 0x55, 0x44, 0x38, 0x44, 0x44,
	    0xe9, 0xd4, 0xa7, 0x46, 0x64, 0x44, 0x03, 0x66, 0x31, 0x8f, 0xff, 0xff,
	    0xff, 0xe9, 0xd4, 0x01, 0xff, 0xa1, 0x33, 0x0b, 0xb1, 0x42, 0x2a, 0x6f,
	    0xf0, 0x27, 0x77, 0x2f, 0x07, 0xec, 0xcb, 0xba, 0x96, 0x00, 0x22, 0x22,
	    0x22, 0x25, 0x54, 0x55, 0x55, 0x55, 0x87, 0xe9, 0x55, 0x44, 0x44, 0x44,
	    0xe9, 0xd4, 0xa7, 0x81, 0x59, 0x66, 0x43, 0x3c, 0xff, 0xff, 0xff, 0xe9,
	    0x80, 0xd4, 0xff, 0xa1, 0x36, 0x0c, 0xb0, 0x46, 0x2a, 0xf8, 0x6f, 0x27,
	    0x77, 0x2f, 0x05, 0xed, 0xbb, 0xa9, 0x00, 0x96, 0x22, 0x22, 0x22, 0x55,
	    0x77, 0x55, 0x77, 0x00, 0x55, 0x55, 0x57, 0x55, 0x55, 0x55, 0x55, 0x44,
	    0x3c, 0x44, 0x44, 0xe9, 0xd4, 0xa7, 0x59, 0x64, 0x46, 0x0c, 0x1a, 0xff,
	    0xff, 0xff, 0xe9, 0xd4, 0xff, 0xa2, 0x07, 0x66, 0x0e, 0xc0, 0x44, 0x2a,
	    0x6f, 0x27, 0x77, 0xc0, 0x2f, 0x03, 0xec, 0xba, 0xa8, 0x23, 0x11, 0x12,
	    0x00, 0x22, 0x44, 0x45, 0x55, 0x55, 0x55, 0x25, 0x44, 0x81, 0xd9, 0x55,
	    0x55, 0x45, 0x44, 0x44, 0x44, 0xe9, 0xe0, 0xd4, 0xa7, 0x59, 0x57, 0x44,
	    0x19, 0xcf, 0xff, 0x30, 0xff, 0xff, 0xe9, 0xd4, 0x72, 0x66, 0x0e, 0xe0,
	    0x1e, 0x44, 0x29, 0xef, 0x6f, 0x27, 0x77, 0x2f, 0xff, 0x00, 0xff, 0xfc,
	    0xbb, 0x93, 0x11, 0x13, 0x33, 0x66, 0x00, 0x66, 0x44, 0x66, 0x44, 0x62,
	    0x55, 0x57, 0x44, 0x00, 0x45, 0x64, 0x44, 0x56, 0x64, 0x44, 0x44, 0x44,
	    0xf0, 0xe9, 0xd4, 0xa7, 0x5b, 0x55, 0x56, 0x23, 0xaf, 0x18, 0xff, 0xff,
	    0xff, 0xe9, 0xd3, 0xfd, 0x42, 0x63, 0x07, 0x0e, 0xe0, 0x66, 0x19, 0xef,
	    0x6f, 0x27, 0x77, 0x80, 0x2f, 0xfe, 0xca, 0x93, 0x31, 0x33, 0x26, 0x66,
	    0x00, 0x26, 0x66, 0x62, 0x67, 0x64, 0x26, 0x44, 0x45, 0x00, 0x55, 0x66,
	    0x64, 0x44, 0x46, 0x66, 0x66, 0x67, 0x0e, 0x66, 0x44, 0x44, 0x44, 0xe9,
	    0xd4, 0xa3, 0x46, 0x40, 0x64, 0x6b, 0x55, 0x72, 0x41, 0x9e, 0xff, 0xff,
	    0x60, 0xff, 0xe9, 0xd3, 0xfd, 0x22, 0x63, 0x0e, 0xe0, 0x1e, 0x66, 0x22,
	    0xef, 0x6f, 0x27, 0x77, 0x2e, 0xec, 0x00, 0x93, 0x11, 0x13, 0x22, 0x66,
	    0x74, 0x44, 0x44, 0x02, 0x26, 0x62, 0x64, 0x44, 0x44, 0x44, 0xe9, 0x66,
	    0x40, 0x66, 0xe9, 0x66, 0x66, 0x47, 0x64, 0x76, 0x47, 0x80, 0x7c, 0x44,
	    0x44, 0x45, 0x45, 0x62, 0x44, 0x46, 0x00, 0x26, 0x46, 0x64, 0x44, 0x44,
	    0x56, 0x76, 0x55, 0x03, 0x55, 0x63, 0x3b, 0xff, 0xff, 0xff, 0xe9, 0xd3,
	    0x00, 0xfd, 0x22, 0x61, 0x1e, 0xe1, 0x24, 0x22, 0xcf, 0xf0, 0x6f, 0x27,
	    0x77, 0x2c, 0xfe, 0xb8, 0x10, 0x22, 0x00, 0x66, 0x66, 0x64, 0x64, 0x44,
	    0x55, 0x55, 0x44, 0x00, 0x74, 0x44, 0x42, 0x44, 0x44, 0x45, 0x55, 0x55,
	    0x00, 0x54, 0x44, 0x44, 0x46, 0x64, 0x66, 0x66, 0x26, 0x0c, 0x66, 0x44,
	    0x44, 0x44, 0xe9, 0xd2, 0x64, 0x74, 0x04, 0x47, 0x42, 0x66, 0x66, 0x66,
	    0xe9, 0x46, 0x66, 0x01, 0x77, 0x56, 0x63, 0x18, 0xff, 0xff, 0xff, 0xe9,
	    0x80, 0xd3, 0xfb, 0x22, 0x61, 0x8f, 0xf3, 0x17, 0x22, 0x78, 0xcf, 0x6f,
	    0x27, 0x77, 0x2b, 0xca, 0x31, 0x11, 0x00, 0x32, 0x26, 0x44, 0x66, 0x47,
	    0x45, 0x55, 0x55, 0x48, 0x55, 0xe9, 0x77, 0x75, 0xe1, 0x55, 0x55, 0x54,
	    0x00, 0x62, 0x44, 0x66, 0x66, 0x64, 0x66, 0x44, 0x67, 0x18, 0x44, 0x44,
	    0x44, 0xe9, 0xd2, 0x76, 0x46, 0x17, 0x10, 0x11, 0x11, 0x11, 0xe9, 0x11,
	    0x11, 0x21, 0x21, 0x03, 0x23, 0x11, 0xbf, 0xff, 0xff, 0xff, 0xe9, 0xd2,
	    0x01, 0xfa, 0x22, 0x61, 0x9f, 0xf8, 0x17, 0x52, 0x77, 0xe0, 0x37, 0x7f,
	    0x32, 0xec, 0xa3, 0x11, 0x13, 0x64, 0x00, 0x44, 0x74, 0x46, 0x66, 0x44,
	    0x55, 0x55, 0x55, 0x0c, 0x55, 0x55, 0x77, 0x75, 0xca, 0xa1, 0x54, 0x47,
	    0x00, 0x62, 0x22, 0x22, 0x22, 0x31, 0x26, 0x24, 0x47, 0x10, 0x44, 0x44,
	    0x44, 0xe9, 0x44, 0x44, 0x72, 0x74, 0x00, 0x46, 0x6b, 0xbb, 0xbb, 0xbb,
	    0xbb, 0xbb, 0xba, 0x00, 0xaa, 0xaa, 0xa9, 0x99, 0x88, 0x10, 0x8f, 0xff,
	    0x30, 0xff, 0xff, 0xe9, 0xd2, 0xf8, 0x22, 0x60, 0xaf, 0x0e, 0xfa, 0x04,
	    0x52, 0xaf, 0x77, 0x2f, 0x77, 0xff, 0x00, 0xec, 0xba, 0x31, 0x13, 0x26,
	    0x54, 0x46, 0x45, 0x00, 0x44, 0x64, 0x44, 0x45, 0x64, 0x44, 0x44, 0x55,
	    0x00, 0x55, 0x75, 0x55, 0x55, 0x55, 0x44, 0x44, 0x62, 0x00, 0x22, 0x22,
	    0x11, 0x11, 0x33, 0x36, 0x99, 0x99, 0x14, 0xa9, 0x36, 0x64, 0x49, 0x44,
	    0xe9, 0x44, 0x44, 0x01, 0x72, 0x46, 0x46, 0x6b, 0xff, 0xff, 0xff, 0xe9,
	    0xc0, 0xd4, 0xa7, 0xff, 0xff, 0xf8, 0x25, 0x20, 0xbf, 0x0e, 0xfb, 0x16,
	    0x52, 0x9f, 0x0f, 0x07, 0x77, 0xcc, 0x00, 0xa9, 0x11, 0x22, 0x24, 0x46,
	    0x26, 0x77, 0x74, 0x00, 0x66, 0x44, 0x44, 0x44, 0x66, 0x64, 0x44, 0x44,
	    0x00, 0x55, 0x56, 0x62, 0x64, 0x66, 0x33, 0x11, 0x10, 0x00, 0x13, 0x39,
	    0xaa, 0xab, 0xbb, 0xcc, 0xee, 0xee, 0x09, 0xeb, 0x16, 0x64, 0x62, 0x29,
	    0x44, 0x54, 0x29, 0x01, 0x74, 0x42, 0x66, 0x16, 0xff, 0xff, 0xff, 0xe9,
	    0xc0, 0xd4, 0xa7, 0xff, 0xff, 0xd8, 0x55, 0x21, 0xcf, 0x0e, 0xfd, 0x12,
	    0x52, 0x6c, 0x0f, 0x07, 0x75, 0xfe, 0x00, 0xcb, 0x91, 0x22, 0x25, 0x55,
	    0x57, 0x44, 0x77, 0x00, 0x44, 0x46, 0x44, 0x44, 0x62, 0x64, 0x44, 0x44,
	    0x00, 0x66, 0x66, 0x26, 0x46, 0x63, 0x11, 0x00, 0x03, 0x0c, 0x8a, 0xab,
	    0xdd, 0xdd, 0x01, 0xe9, 0xfb, 0x03, 0x08, 0x67, 0x44, 0x44, 0x44, 0xe9,
	    0x44, 0x44, 0x55, 0x07, 0x54, 0x46, 0x47, 0x61, 0xdf, 0x4c, 0x1c, 0xa7,
	    0x00, 0xff, 0xb3, 0x55, 0x23, 0xef, 0xfe, 0x32, 0x72, 0x70, 0x3c, 0x17,
	    0x07, 0x04, 0xfe, 0xb8, 0x11, 0x11, 0x00, 0x55, 0x55, 0x55, 0x52, 0x44,
	    0x55, 0x77, 0x77, 0x00, 0x46, 0x64, 0x44, 0x62, 0x44, 0x44, 0x66, 0x66,
	    0x01, 0x23, 0x11, 0x13, 0x8a, 0xbb, 0xcd, 0xef, 0x03, 0x80, 0xda, 0xfc,
	    0x13, 0x66, 0x66, 0x44, 0x44, 0x44, 0x80, 0xe9, 0x44, 0x55, 0x74, 0x44,
	    0x46, 0x61, 0xbf, 0xe0, 0x37, 0xbf, 0x72, 0xb0, 0x55, 0x29, 0xef, 0xff,
	    0x1c, 0x92, 0x56, 0x1b, 0x17, 0x07, 0x03, 0xec, 0xa6, 0x00, 0x12, 0x45,
	    0x55, 0x44, 0x44, 0x44, 0x44, 0x44, 0x00, 0x74, 0x66, 0x44, 0x77, 0x42,
	    0x66, 0x66, 0x22, 0x01, 0x33, 0x11, 0x13, 0x88, 0xab, 0xdd, 0xef, 0x05,
	    0x80, 0xcb, 0xfe, 0x31, 0x55, 0x55, 0x55, 0x44, 0x44, 0x63, 0x44, 0xe9,
	    0xd1, 0x47, 0x42, 0x9f, 0x1f, 0xbf, 0x80, 0x72, 0xa1, 0x66, 0x1a, 0xff,
	    0xfe, 0xa2, 0x56, 0x70, 0x18, 0x17, 0x07, 0x02, 0xeb, 0x91, 0x22, 0x24,
	    0x04, 0x42, 0x25, 0x44, 0x44, 0x44, 0xe9, 0x64, 0x74, 0x00, 0x44, 0x46,
	    0x63, 0x11, 0x11, 0x13, 0x8a, 0xbd, 0x60, 0xef, 0x07, 0xbd, 0x81, 0x55,
	    0x55, 0x55, 0x44, 0x31, 0x44, 0x44, 0xe9, 0xd1, 0x47, 0x42, 0x6e, 0x07,
	    0xc0, 0xbf, 0x72, 0x93, 0x66, 0x1b, 0xff, 0xff, 0xb2, 0x38, 0x54, 0x18,
	    0x17, 0x07, 0x01, 0xdb, 0x30, 0x16, 0x00, 0x22, 0x74, 0x55, 0x55, 0x44,
	    0x44, 0x44, 0x44, 0x00, 0x74, 0x44, 0x44, 0x47, 0x56, 0x31, 0x33, 0x39,
	    0x18, 0xaa, 0xce, 0xef, 0x07, 0xbf, 0x81, 0x55, 0x55, 0x08, 0x55, 0x44,
	    0x44, 0x44, 0xe9, 0x44, 0x54, 0x44, 0x1c, 0x44, 0x42, 0x3c, 0x07, 0xbf,
	    0x71, 0xfe, 0x23, 0x86, 0x3a, 0xc2, 0x27, 0x31, 0xdf, 0x0f, 0x07, 0xff,
	    0x00, 0xda, 0x31, 0x16, 0x42, 0x75, 0x62, 0x55, 0x55, 0x00, 0x44, 0x44,
	    0x44, 0x44, 0x74, 0x44, 0x74, 0x22, 0x06, 0x33, 0x39, 0xaa, 0xbc, 0xee,
	    0x07, 0xbf, 0xff, 0x00, 0xff, 0xa1, 0x55, 0x55, 0x55, 0x44, 0x44, 0x44,
	    0xce, 0xe9, 0xd2, 0x46, 0x1b, 0x07, 0xbf, 0x71, 0xfc, 0x00, 0x03, 0x41,
	    0x9e, 0xff, 0xff, 0xe6, 0x25, 0x21, 0x60, 0xbf, 0x0f, 0x07, 0xfd, 0x11,
	    0x33, 0x27, 0x75, 0x00, 0x25, 0x74, 0x55, 0x55, 0x44, 0x44, 0x44, 0x44,
	    0x01, 0x44, 0x54, 0x76, 0x67, 0x9a, 0xbc, 0xef, 0x07, 0xc0, 0xbf, 0x72,
	    0xa1, 0x25, 0x55, 0x55, 0x44, 0x44, 0x67, 0x44, 0xe9, 0xd2, 0x46, 0x1a,
	    0x07, 0xbf, 0x71, 0x00, 0xfa, 0x06, 0x61, 0x9e, 0xff, 0xff, 0xea, 0x22,
	    0x30, 0x41, 0x9f, 0x0f, 0x07, 0xfd, 0x11, 0x36, 0x25, 0x00, 0x75, 0x54,
	    0x74, 0x55, 0x47, 0x44, 0x44, 0x44, 0x03, 0x44, 0x44, 0x66, 0x46, 0x47,
	    0xce, 0x07, 0xbf, 0x80, 0x74, 0xa1, 0x55, 0x55, 0x55, 0x44, 0x44, 0x44,
	    0xdc, 0xe9, 0xd3, 0x1a, 0x07, 0xbf, 0x71, 0xf8, 0x16, 0x00, 0x21, 0xae,
	    0xff, 0xff, 0xeb, 0x22, 0x43, 0x3e, 0xc0, 0x0f, 0x07, 0xff, 0x93, 0x34,
	    0x65, 0x55, 0x75, 0x04, 0x44, 0x44, 0x47, 0x44, 0x44, 0xd9, 0x66, 0x42,
	    0x38, 0x59, 0xef, 0x07, 0xbf, 0x74, 0xb1, 0x25, 0x55, 0x0c, 0x55, 0x44,
	    0x44, 0x44, 0xe9, 0xd2, 0x45, 0x1a, 0xe0, 0x07, 0xbf, 0x71, 0xc1, 0x36,
	    0x23, 0xce, 0xff, 0x06, 0xff, 0xfc, 0x22, 0x72, 0x1c, 0x0f, 0x07, 0xff,
	    0x00, 0xa3, 0x34, 0x47, 0x55, 0x44, 0x44, 0x44, 0x47, 0x81, 0xe1, 0x44,
	    0x47, 0x66, 0x42, 0x27, 0xde, 0x07, 0xc0, 0xbf, 0x74, 0xb1, 0x25, 0x55,
	    0x55, 0x44, 0x44, 0x6e, 0x44, 0xe9, 0xd3, 0x39, 0x07, 0xbf, 0x71, 0xb1,
	    0x00, 0x62, 0x33, 0xcf, 0xff, 0xff, 0xfe, 0x92, 0x44, 0x60, 0x1a, 0x0f,
	    0x07, 0xff, 0xc3, 0x33, 0x44, 0x57, 0x10, 0x44, 0x44, 0x44, 0xe9, 0x44,
	    0x44, 0x74, 0x44, 0x1c, 0x44, 0x22, 0xae, 0x07, 0xbf, 0x74, 0xc1, 0x25,
	    0x03, 0x55, 0x55, 0x46, 0x44, 0x44, 0x44, 0xe9, 0xd2, 0x70, 0x18, 0x07,
	    0xbf, 0x71, 0x91, 0x62, 0x1a, 0xef, 0x03, 0xff, 0xff, 0xfe, 0xa2, 0x25,
	    0x29, 0xc9, 0x07, 0x80, 0x05, 0xea, 0x33, 0x64, 0x47, 0x44, 0x66, 0x64,
	    0x10, 0x44, 0x44, 0x44, 0xe9, 0x44, 0x46, 0x22, 0x8e, 0xe0, 0x07, 0xbf,
	    0x74, 0xc1, 0x25, 0x55, 0x55, 0x46, 0x1b, 0x44, 0x44, 0x44, 0xe9, 0xd2,
	    0x18, 0x07, 0xbf, 0x01, 0xff, 0xff, 0xfe, 0x22, 0x22, 0x3b, 0xef, 0x39,
	    0x0c, 0xb3, 0x25, 0x41, 0xcf, 0x07, 0x07, 0xfc, 0x13, 0x05, 0x66, 0x44,
	    0x44, 0x46, 0x66, 0xd9, 0x44, 0xe9, 0x0e, 0x46, 0x22, 0x8c, 0xef, 0x07,
	    0xbf, 0x73, 0xb1, 0x01, 0x25, 0x55, 0x55, 0x46, 0x44, 0x44, 0x44, 0xe9,
	    0xb0, 0xd2, 0x1a, 0x07, 0xbf, 0xff, 0xff, 0xfb, 0x16, 0x10, 0x25, 0x8c,
	    0xef, 0x39, 0xd9, 0x25, 0x21, 0xbf, 0xc0, 0x07, 0x07, 0xfe, 0x83, 0x66,
	    0x44, 0x44, 0x44, 0x63, 0x44, 0xdb, 0xb9, 0x62, 0x3b, 0xef, 0x07, 0xbf,
	    0x80, 0x73, 0xb1, 0x25, 0x55, 0x55, 0x46, 0x44, 0x44, 0x6c, 0x44, 0xe9,
	    0xd2, 0x1a, 0x07, 0xbf, 0xff, 0xff, 0x08, 0xfa, 0x15, 0x25, 0x8e, 0x42,
	    0xf9, 0x24, 0x23, 0x60, 0x8d, 0x07, 0x07, 0xff, 0xb3, 0x37, 0x44, 0x44,
	    0x63, 0x44, 0xe9, 0xd4, 0x46, 0x19, 0xee, 0x07, 0xbf, 0x80, 0x73, 0xb1,
	    0x25, 0x55, 0x55, 0x46, 0x44, 0x44, 0x6c, 0x44, 0xe9, 0xd2, 0x1a, 0x07,
	    0xbf, 0xff, 0xff, 0x08, 0xc8, 0x35, 0x52, 0xaf, 0x42, 0xfb, 0x22, 0x26,
	    0x60, 0x1d, 0x07, 0x07, 0xff, 0xd8, 0x12, 0x44, 0x44, 0x0c, 0x54, 0x44,
	    0x44, 0x44, 0xe9, 0xd2, 0x33, 0xce, 0xe0, 0x07, 0xbf, 0x73, 0xa1, 0x25,
	    0x55, 0x55, 0x46, 0x1b, 0x44, 0x44, 0x44, 0xe9, 0xd2, 0x1b, 0x07, 0xbf,
	    0x02, 0xff, 0xff, 0xb1, 0x35, 0x52, 0xdf, 0x42, 0xfc, 0x18, 0x62, 0x66,
	    0x0a, 0x07, 0x07, 0xff, 0xfa, 0x32, 0x03, 0x65, 0x44, 0x54, 0x44, 0x44,
	    0x44, 0xe9, 0xd1, 0x1c, 0x54, 0x31, 0xae, 0x07, 0xbf, 0x73, 0xa1, 0x25,
	    0x03, 0x55, 0x55, 0x46, 0x44, 0x44, 0x44, 0xe9, 0xd2, 0x60, 0x1b, 0x07,
	    0xbf, 0xff, 0xff, 0x81, 0x25, 0x57, 0x83, 0x4b, 0xfe, 0x96, 0x23, 0x18,
	    0xdf, 0x07, 0x07, 0x00, 0xfc, 0x62, 0x45, 0x54, 0x45, 0x54, 0x44, 0x44,
	    0x67, 0x44, 0xe9, 0xd1, 0x61, 0x3e, 0x07, 0xbf, 0x73, 0x00, 0xa1, 0x27,
	    0x55, 0x55, 0x46, 0x44, 0x44, 0x44, 0xd8, 0xe9, 0xd2, 0x3c, 0x07, 0xbf,
	    0xff, 0xfd, 0x33, 0x21, 0x25, 0x2b, 0x4c, 0xc1, 0x66, 0x22, 0xbf, 0x07,
	    0x80, 0x07, 0xff, 0x81, 0x93, 0x76, 0x24, 0x45, 0x55, 0x10, 0x44, 0x44,
	    0x44, 0xe9, 0x44, 0x44, 0x72, 0x1b, 0x71, 0xef, 0x07, 0xbf, 0x72, 0x81,
	    0x67, 0x27, 0x02, 0x81, 0xe1, 0x45, 0x55, 0x54, 0x26, 0x63, 0x3f, 0x07,
	    0x82, 0xbf, 0xff, 0xfa, 0x24, 0x23, 0x3d, 0x4c, 0xd9, 0x18, 0x36, 0x23,
	    0xad, 0x07, 0x07, 0xff, 0xc1, 0x33, 0x01, 0x66, 0x44, 0x45, 0x55, 0x44,
	    0x44, 0x44, 0xe9, 0x07, 0x44, 0x44, 0x56, 0x19, 0xee, 0x07, 0xbf, 0x71,
	    0x0c, 0xfe, 0x33, 0x64, 0x24, 0x02, 0xe1, 0x45, 0x55, 0x0c, 0x55, 0x74,
	    0x63, 0x9f, 0x07, 0xbf, 0xff, 0xe9, 0x10, 0x26, 0x61, 0x8e, 0x4c, 0xeb,
	    0x16, 0x61, 0x3d, 0xc0, 0x07, 0x07, 0xff, 0xfa, 0x13, 0x66, 0x44, 0x55,
	    0x08, 0x55, 0x44, 0x44, 0x44, 0xe9, 0x44, 0x44, 0x55, 0x38, 0x21, 0xcf,
	    0x07, 0xbf, 0x71, 0xfc, 0x13, 0x64, 0x60, 0x45, 0x02, 0xe1, 0x45, 0x55,
	    0x55, 0x72, 0x61, 0x60, 0xbf, 0x07, 0xbf, 0xff, 0xb3, 0x26, 0x31, 0xcf,
	    0x86, 0x4c, 0xfc, 0x12, 0x91, 0x1b, 0x07, 0x07, 0xff, 0x00, 0xfc, 0x33,
	    0x66, 0x24, 0x55, 0x55, 0x44, 0x44, 0x41, 0x44, 0xe9, 0x44, 0x44, 0x55,
	    0x61, 0x9f, 0x07, 0xc2, 0xbf, 0x71, 0xfb, 0x06, 0x64, 0x75, 0x02, 0x45,
	    0x83, 0xe9, 0x57, 0x57, 0x22, 0x50, 0xef, 0x07, 0xbf, 0x08, 0xfe, 0x92,
	    0x46, 0x18, 0x4d, 0xfe, 0xa0, 0x62, 0xe0, 0xae, 0x07, 0x32, 0xa1, 0x36,
	    0x44, 0x55, 0x55, 0x10, 0x44, 0x44, 0x44, 0xe9, 0x44, 0x44, 0x55, 0x42,
	    0x70, 0x1c, 0x07, 0xbf, 0x71, 0xea, 0x06, 0x66, 0x74, 0xc1, 0x02, 0xe1,
	    0x45, 0x55, 0x75, 0x27, 0x19, 0x07, 0x81, 0xbf, 0xff, 0xfc, 0x32, 0x76,
	    0x1b, 0xef, 0x45, 0x0c, 0xc1, 0x16, 0x31, 0xbf, 0x07, 0xbf, 0xff, 0xf3,
	    0x01, 0x16, 0x75, 0x55, 0x75, 0x44, 0x44, 0x44, 0xe9, 0x07, 0x44, 0x44,
	    0x55, 0x72, 0x18, 0x07, 0xbf, 0x71, 0x0c, 0xe8, 0x16, 0x67, 0x74, 0x02,
	    0xe1, 0x55, 0x55, 0x18, 0x72, 0x49, 0x0c, 0x07, 0xbf, 0xff, 0xea, 0x12,
	    0x21, 0x61, 0x3e, 0x4e, 0xe9, 0x13, 0x61, 0x9e, 0x07, 0x80, 0xbf, 0xff,
	    0xfb, 0x12, 0x44, 0x55, 0x55, 0x44, 0x20, 0x44, 0x44, 0xe9, 0x44, 0x44,
	    0x55, 0x52, 0x21, 0x61, 0xbe, 0x07, 0xbf, 0xff, 0xff, 0xb1, 0x36, 0x04,
	    0x00, 0x54, 0x44, 0x45, 0x55, 0x55, 0x72, 0x63, 0x1e, 0xc1, 0x07, 0xbf,
	    0xff, 0xc3, 0x16, 0x21, 0xae, 0x4e, 0x0c, 0xfb, 0x33, 0x62, 0x1b, 0x07,
	    0xbf, 0xff, 0xff, 0x01, 0x93, 0x14, 0x75, 0x55, 0x44, 0x44, 0x44, 0xe9,
	    0x03, 0x44, 0x44, 0x57, 0x24, 0x23, 0x3e, 0x07, 0xbf, 0x02, 0xff, 0xff,
	    0xa0, 0x62, 0x44, 0x54, 0x02, 0x44, 0x01, 0x45, 0x45, 0x55, 0x55, 0x54,
	    0x60, 0xbf, 0x07, 0x82, 0xbf, 0xfe, 0xb0, 0x66, 0x11, 0xce, 0x9f, 0x81,
	    0x18, 0x27, 0x22, 0xef, 0x07, 0xbf, 0xff, 0xe3, 0x17, 0x04, 0x45, 0x75,
	    0x44, 0x44, 0x44, 0xe9, 0x44, 0x44, 0x0c, 0x55, 0x54, 0x61, 0x39, 0x07,
	    0xbf, 0xff, 0xfd, 0x08, 0x13, 0x64, 0x45, 0x54, 0x02, 0x44, 0x44, 0x45,
	    0x0c, 0x54, 0x57, 0x24, 0x11, 0x07, 0xbf, 0xff, 0xfc, 0x08, 0x13, 0x66,
	    0x1a, 0xef, 0x47, 0xb1, 0x26, 0x22, 0x60, 0xbf, 0x07, 0x57, 0xff, 0xfb,
	    0x31, 0x62, 0x67, 0x10, 0x44, 0x44, 0x44, 0xe9, 0x44, 0x44, 0x55, 0x65,
	    0x18, 0x46, 0x23, 0xcf, 0x07, 0xbf, 0xf8, 0x22, 0x64, 0x28, 0x45, 0x55,
	    0x01, 0x47, 0xe1, 0x55, 0x55, 0x56, 0x60, 0x0b, 0x07, 0xbf, 0xff, 0xfa,
	    0x16, 0x63, 0x3b, 0x83, 0x4f, 0xff, 0xe8, 0x32, 0x52, 0x3e, 0x07, 0x4f,
	    0x00, 0xff, 0xfe, 0xa1, 0x36, 0x24, 0x44, 0x44, 0x44, 0x80, 0xe9, 0x44,
	    0x44, 0x54, 0x45, 0x74, 0x21, 0x9e, 0xc1, 0x07, 0xbf, 0xc1, 0x26, 0x44,
	    0x55, 0x54, 0x01, 0x00, 0x45, 0x74, 0x54, 0x44, 0x55, 0x52, 0x41, 0x8f,
	    0xc1, 0x07, 0xbf, 0xff, 0xc1, 0x17, 0x61, 0x9e, 0x4f, 0x06, 0xff, 0xfb,
	    0x32, 0x65, 0x0b, 0x07, 0x4f, 0xff, 0x01, 0xff, 0xc9, 0x13, 0x62, 0x44,
	    0x44, 0x44, 0xe9, 0x00, 0x44, 0x44, 0x24, 0x45, 0x54, 0x62, 0x1a, 0xef,
	    0xc0, 0x07, 0xbe, 0x93, 0x64, 0x54, 0x55, 0x54, 0x44, 0x00, 0x46, 0x44,
	    0x45, 0x44, 0x44, 0x44, 0x55, 0x55, 0x30, 0x21, 0xcf, 0x07, 0xbf, 0xff,
	    0x91, 0x66, 0x33, 0x80, 0x4f, 0xff, 0xff, 0xfe, 0x91, 0x27, 0x30, 0xef,
	    0xc0, 0x07, 0x47, 0xff, 0xfb, 0x31, 0x33, 0x44, 0x44, 0x40, 0x44, 0xe9,
	    0x44, 0x44, 0x64, 0x54, 0x55, 0x54, 0x30, 0x40, 0xbe, 0x07, 0x04, 0xfe,
	    0xfc, 0x12, 0x45, 0x00, 0x55, 0x55, 0x54, 0x44, 0x46, 0x44, 0x45, 0x44,
	    0x06, 0x44, 0x54, 0x65, 0x52, 0x1a, 0x07, 0xbf, 0xff, 0x04, 0xfb, 0x12,
	    0x42, 0x1a, 0xef, 0x47, 0xff, 0xff, 0x0c, 0xb3, 0x36, 0x60, 0x9f, 0x07,
	    0x47, 0xff, 0xfe, 0x06, 0xa1, 0x09, 0x44, 0x44, 0x44, 0xe9, 0xd1, 0x64,
	    0x06, 0x75, 0x55, 0x22, 0x3c, 0xef, 0x07, 0xbc, 0xc9, 0x04, 0x16, 0x54,
	    0x55, 0x55, 0x54, 0x01, 0x45, 0x44, 0x06, 0x44, 0x56, 0x65, 0x50, 0x4e,
	    0x0f, 0xbf, 0xff, 0x0c, 0xf3, 0x14, 0x23, 0x3c, 0x4f, 0x01, 0xe9, 0x33,
	    0x30, 0x36, 0x0c, 0x07, 0x3f, 0xff, 0xff, 0xea, 0x13, 0x08, 0x54, 0x44,
	    0x44, 0x44, 0xe9, 0x44, 0x44, 0x64, 0x06, 0x75, 0x55, 0x27, 0x21, 0xce,
	    0x07, 0x03, 0xfd, 0x02, 0x91, 0x66, 0x55, 0x55, 0x55, 0x54, 0x01, 0x45,
	    0x03, 0x64, 0x44, 0x44, 0x62, 0x22, 0xbe, 0x0f, 0xbf, 0x06, 0xff, 0xb1,
	    0x66, 0x23, 0xaf, 0x4f, 0x01, 0xeb, 0x18, 0x33, 0x36, 0x33, 0x07, 0x3f,
	    0xff, 0xff, 0xfe, 0x04, 0xa0, 0x65, 0x44, 0x44, 0x44, 0xe9, 0x44, 0x64,
	    0x03, 0x45, 0x45, 0x57, 0x52, 0x60, 0x1c, 0x07, 0x03, 0x00, 0xd8, 0x03,
	    0x66, 0x55, 0x55, 0x55, 0x54, 0x44, 0x00, 0x44, 0x54, 0x45, 0x66, 0x44,
	    0x44, 0x62, 0x2b, 0x60, 0xef, 0x0f, 0xbf, 0xfe, 0x33, 0x42, 0x43, 0xcf,
	    0xc3, 0x7f, 0x7a, 0x88, 0x57, 0x51, 0xbf, 0x7f, 0x37, 0x00, 0xff, 0xff,
	    0xd8, 0x16, 0x74, 0x22, 0x75, 0x55, 0x00, 0x55, 0x46, 0x66, 0x55, 0x55,
	    0x55, 0x55, 0x55, 0x18, 0x77, 0x13, 0xbe, 0x07, 0x01, 0xec, 0x91, 0x25,
	    0x00, 0x42, 0x44, 0x44, 0x54, 0x45, 0x54, 0x44, 0x44, 0x03, 0x44, 0x75,
	    0x44, 0x26, 0x61, 0x8e, 0x1f, 0xbf, 0x03, 0xff, 0xea, 0x13, 0x31, 0x8a,
	    0xef, 0x47, 0x02, 0x0c, 0xc8, 0x25, 0x26, 0x3c, 0x7f, 0x37, 0xff, 0xff,
	    0x00, 0xfd, 0x91, 0x36, 0x47, 0x57, 0x55, 0x55, 0x46, 0x00, 0x66, 0x45,
	    0x55, 0x55, 0x55, 0x57, 0x52, 0x71, 0x20, 0x1a, 0xee, 0x07, 0xff, 0xfe,
	    0xb9, 0x12, 0x74, 0x08, 0x55, 0x44, 0x44, 0x44, 0xe9, 0x44, 0x44, 0x57,
	    0x0c, 0x42, 0x42, 0x33, 0xcf, 0x27, 0xbf, 0xff, 0xc3, 0x18, 0x33, 0x33,
	    0x3e, 0x4f, 0x03, 0xfa, 0x17, 0x22, 0x30, 0x39, 0xef, 0x6f, 0x27, 0xff,
	    0xff, 0xe3, 0x13, 0x00, 0x67, 0x55, 0x55, 0x55, 0x44, 0x66, 0x44, 0x44,
	    0x82, 0xc9, 0x55, 0x72, 0x12, 0xac, 0xef, 0x07, 0xca, 0x01, 0x21, 0x26,
	    0x62, 0x57, 0x44, 0x44, 0x44, 0xe9, 0x03, 0x54, 0x66, 0x54, 0x64, 0x61,
	    0x3b, 0x37, 0xbf, 0x03, 0xff, 0xfe, 0x91, 0x33, 0x31, 0xbf, 0x47, 0x03,
	    0x0e, 0xfd, 0x26, 0x26, 0x13, 0x6f, 0x2f, 0x01, 0xfe, 0x00, 0x81, 0x34,
	    0x45, 0x55, 0x55, 0x55, 0x44, 0x66, 0x00, 0x44, 0x44, 0x45, 0x52, 0x77,
	    0x25, 0x72, 0x03, 0x20, 0xac, 0xef, 0x3d, 0xca, 0x91, 0x16, 0x62, 0x67,
	    0x40, 0x72, 0x49, 0x44, 0x44, 0x44, 0x44, 0x44, 0x46, 0x1c, 0x76, 0x13,
	    0xbf, 0x3c, 0x0c, 0xa5, 0xfa, 0x26, 0x30, 0x33, 0x18, 0x4f, 0x05, 0xc0,
	    0x92, 0x61, 0x9c, 0xe0, 0x67, 0x1f, 0x01, 0xea, 0x11, 0x76, 0x55, 0x55,
	    0x00, 0x55, 0x55, 0x66, 0x66, 0x64, 0x44, 0x74, 0x55, 0x00, 0x55, 0x57,
	    0x63, 0x13, 0x9b, 0xce, 0xff, 0xff, 0x00, 0xfe, 0xee, 0xec, 0xb9, 0x31,
	    0x36, 0x62, 0x26, 0x02, 0x44, 0x64, 0x44, 0x44, 0x44, 0x54, 0xe1, 0x44,
	    0x03, 0x47, 0x61, 0x3b, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0x86, 0xa6, 0xb3,
	    0x27, 0x61, 0x1e, 0x47, 0x05, 0xea, 0x0e, 0x03, 0x22, 0x19, 0xef, 0x5f,
	    0x17, 0x01, 0xa1, 0x00, 0x12, 0x45, 0x55, 0x55, 0x55, 0x66, 0x66, 0x66,
	    0x00, 0x66, 0x67, 0x62, 0x74, 0x25, 0x62, 0x66, 0x31, 0x00, 0x39, 0xbb,
	    0xbc, 0xcb, 0xaa, 0x93, 0x11, 0x26, 0x00, 0x22, 0x62, 0x67, 0x42, 0x67,
	    0x44, 0x44, 0x44, 0x20, 0x44, 0x54, 0xd9, 0x42, 0x13, 0xbf, 0xff, 0xff,
	    0x70, 0xff, 0xe9, 0xd4, 0xa5, 0xfe, 0x61, 0x26, 0x60, 0xc1, 0x47, 0x06,
	    0xee, 0x30, 0x91, 0x23, 0xbe, 0x5f, 0xc0, 0x17, 0x01, 0xfa, 0x03, 0x64,
	    0x55, 0x55, 0x55, 0x00, 0x45, 0x54, 0x46, 0x66, 0x64, 0x44, 0x47, 0x72,
	    0x00, 0x55, 0x54, 0x46, 0x21, 0x11, 0x11, 0x11, 0x11, 0x00, 0x22, 0x64,
	    0x46, 0x66, 0x44, 0x66, 0x47, 0x42, 0x00, 0x44, 0x45, 0x45, 0x55, 0x44,
	    0x44, 0x54, 0x44, 0x07, 0x21, 0x3b, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0xa6,
	    0x0c, 0xfa, 0x12, 0x62, 0x19, 0x47, 0x07, 0xc0, 0x39, 0x38, 0x42, 0x4c,
	    0x57, 0x0f, 0x02, 0xc1, 0x12, 0x25, 0x00, 0x55, 0x55, 0x44, 0x44, 0x44,
	    0x44, 0x42, 0x67, 0x00, 0x45, 0x57, 0x55, 0x55, 0x54, 0x44, 0x22, 0x22,
	    0x00, 0x24, 0x66, 0x44, 0x46, 0x64, 0x46, 0x74, 0x74, 0x00, 0x66, 0x67,
	    0x44, 0x45, 0x55, 0x55, 0x55, 0x55, 0x01, 0x46, 0x65, 0x13, 0xbf, 0xff,
	    0xff, 0xff, 0xe9, 0xc3, 0xd4, 0xa6, 0xa1, 0x36, 0x61, 0x1e, 0x47, 0x07,
	    0x07, 0xfb, 0x02, 0x42, 0x19, 0xee, 0x4f, 0x07, 0x01, 0x00, 0xee, 0x86,
	    0x62, 0x25, 0x55, 0x57, 0x75, 0x44, 0x00, 0x77, 0x45, 0x44, 0x44, 0x47,
	    0x55, 0x55, 0x55, 0x0f, 0x66, 0x44, 0x44, 0x44, 0xe9, 0xd4, 0x81, 0x69,
	    0x03, 0x56, 0x22, 0x9b, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0x83, 0xa6, 0xfc,
	    0x33, 0x36, 0x21, 0xce, 0x3f, 0x07, 0x07, 0xfe, 0x91, 0x24, 0x46, 0x9e,
	    0x4f, 0x07, 0x02, 0x00, 0xeb, 0x31, 0x24, 0x75, 0x77, 0x55, 0x57, 0x42,
	    0x00, 0x46, 0x45, 0x44, 0x47, 0x55, 0x55, 0x54, 0x44, 0x30, 0x44, 0x44,
	    0xe9, 0xd4, 0x44, 0x55, 0x55, 0x55, 0x81, 0x69, 0x52, 0x2a, 0xcf, 0xff,
	    0xff, 0xff, 0xe9, 0xc3, 0xd4, 0xa6, 0xc9, 0x16, 0x26, 0x1a, 0x47, 0x07,
	    0x03, 0xff, 0xff, 0xc3, 0x16, 0x42, 0x1b, 0x47, 0x07, 0x80, 0x03, 0xca,
	    0x31, 0x25, 0x75, 0x55, 0x55, 0x57, 0x03, 0x44, 0x44, 0x44, 0x46, 0x55,
	    0x54, 0xd1, 0xb9, 0x80, 0xd4, 0x46, 0x77, 0x44, 0x55, 0x77, 0x77, 0x67,
	    0x03, 0x72, 0x13, 0xae, 0xff, 0xff, 0xff, 0xe9, 0xd4, 0x83, 0xa6, 0xfe,
	    0x91, 0x16, 0x21, 0x9e, 0x3f, 0x07, 0x01, 0xff, 0xff, 0xeb, 0x31, 0x66,
	    0x21, 0xcf, 0x3f, 0xc0, 0x07, 0x02, 0xfe, 0xb9, 0x31, 0x55, 0x57, 0x55,
	    0x05, 0x24, 0x44, 0x44, 0x44, 0x66, 0xe1, 0x47, 0xc1, 0xc0, 0xa9, 0xd4,
	    0x74, 0x65, 0x67, 0x66, 0x62, 0x11, 0x07, 0x9c, 0xef, 0xff, 0xff, 0xff,
	    0xe9, 0xd4, 0xa6, 0x06, 0xfb, 0x11, 0x66, 0x13, 0xcf, 0x3f, 0x07, 0xff,
	    0x03, 0xff, 0xfe, 0xa1, 0x66, 0x21, 0x3c, 0x3f, 0x27, 0x80, 0x24, 0xb9,
	    0x12, 0x57, 0x42, 0x67, 0x54, 0x44, 0x0e, 0x54, 0x44, 0x44, 0x44, 0xe9,
	    0xd4, 0xa5, 0x66, 0x01, 0x23, 0x11, 0x3b, 0xef, 0xff, 0xff, 0xff, 0xe9,
	    0xc3, 0xd4, 0xa7, 0xc1, 0x36, 0x33, 0x1b, 0x3f, 0x07, 0x83, 0x02, 0xe9,
	    0x13, 0x66, 0x18, 0xdf, 0x2f, 0x07, 0x80, 0x03, 0xee, 0xb9, 0x10, 0x36,
	    0x45, 0x55, 0x44, 0x11, 0x44, 0x46, 0x64, 0xe1, 0x44, 0x44, 0x44, 0xe9,
	    0x80, 0xd4, 0x66, 0x44, 0x63, 0x31, 0x3a, 0xcf, 0xff, 0x38, 0xff, 0xff,
	    0xe9, 0xd4, 0xa7, 0xfc, 0x91, 0x29, 0x38, 0x11, 0xae, 0x37, 0x2f, 0x2b,
	    0x33, 0x62, 0x60, 0x70, 0x8e, 0x2f, 0x07, 0x04, 0xfd, 0xca, 0x31, 0x14,
	    0x00, 0x55, 0x54, 0x44, 0x46, 0x66, 0x74, 0x44, 0x66, 0x18, 0x44, 0x44,
	    0x44, 0xe9, 0xd4, 0x66, 0x63, 0x13, 0x3c, 0x38, 0xcf, 0x01, 0xe9, 0xd4,
	    0xa7, 0xff, 0xc8, 0x0e, 0x16, 0x26, 0x19, 0xee, 0x2f, 0x07, 0x02, 0xfe,
	    0x0e, 0xc2, 0x12, 0x39, 0x08, 0x2f, 0x07, 0x06, 0xca, 0x00, 0x61, 0x25,
	    0x55, 0x77, 0x77, 0x66, 0x66, 0x44, 0x06, 0x44, 0x44, 0x56, 0x66, 0x67,
	    0xd1, 0xb9, 0x44, 0x07, 0x44, 0x43, 0x11, 0x3a, 0xcf, 0x04, 0xd4, 0xa7,
	    0x01, 0xff, 0xfd, 0x81, 0x32, 0x71, 0x3e, 0xef, 0x27, 0xc1, 0x07, 0x03,
	    0xfa, 0x11, 0x67, 0x62, 0x9e, 0x27, 0xc0, 0x07, 0x06, 0xfd, 0x81, 0x01,
	    0x31, 0x13, 0x64, 0x02, 0x46, 0x22, 0x22, 0x55, 0x55, 0x55, 0xe9, 0x55,
	    0x01, 0x76, 0x22, 0x23, 0x21, 0x11, 0x00, 0x8d, 0x07, 0xc1, 0xbf, 0x74,
	    0xc7, 0x25, 0x55, 0x31, 0xcf, 0x1f, 0xc0, 0x07, 0x04, 0xfe, 0xb3, 0x14,
	    0x52, 0x09, 0xef, 0xe0, 0x17, 0x07, 0x77, 0xca, 0x98, 0x30, 0x11, 0x26,
	    0x04, 0x44, 0x45, 0x55, 0x55, 0x55, 0xe9, 0x55, 0x66, 0x07, 0x23, 0x11,
	    0x13, 0x99, 0xdd, 0x07, 0xbf, 0x74, 0x03, 0xfe, 0x91, 0x55, 0x72, 0x1c,
	    0xef, 0x17, 0x07, 0x83, 0x05, 0xfa, 0x01, 0x72, 0x60, 0xaf, 0x17, 0x07,
	    0x80, 0x77, 0xff, 0xfe, 0xcb, 0xa9, 0x31, 0x11, 0x11, 0x02, 0x33, 0x12,
	    0x22, 0x22, 0x22, 0x22, 0xc1, 0x9a, 0x38, 0xbc, 0xef, 0x07, 0xbf, 0x75,
	    0xf9, 0x15, 0x55, 0x38, 0x21, 0xbf, 0x17, 0x07, 0x06, 0xfe, 0x91, 0x36,
	    0x3c, 0x46, 0x19, 0x0f, 0x07, 0x77, 0x29, 0xee, 0xee, 0x00, 0xcb, 0xaa,
	    0x99, 0x98, 0x99, 0x99, 0x99, 0x99, 0x1c, 0xaa, 0xbb, 0xce, 0x07, 0x07,
	    0x77, 0xfe, 0x91, 0x1c, 0x65, 0x22, 0x1a, 0x07, 0x07, 0x77, 0xff, 0xea,
	    0x0f, 0x13, 0x66, 0x61, 0x9e, 0x07, 0x07, 0x77, 0x2f, 0xf0, 0x07, 0x07,
	    0x07, 0x04, 0xe9, 0x02, 0x76, 0x21, 0x70, 0xaf, 0x07, 0x07, 0x77, 0xff,
	    0xfe, 0xa1, 0x62, 0x3f, 0x44, 0x19, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x07,
	    0xc0, 0x07, 0x03, 0xfd, 0x71, 0x25, 0x22, 0x3a, 0xef, 0xe0, 0x07, 0x07,
	    0x77, 0xff, 0xff, 0xe8, 0x16, 0x64, 0x3f, 0x41, 0x9f, 0x07, 0x07, 0x77,
	    0x2f, 0x07, 0x07, 0xc1, 0x07, 0x02, 0xc8, 0x25, 0x27, 0x60, 0xae, 0x07,
	    0xe0, 0x07, 0x77, 0x29, 0xfd, 0x91, 0x32, 0x55, 0x16, 0x7f, 0xef, 0x07,
	    0x07, 0x77, 0x2f, 0x07, 0x07, 0x07, 0x00, 0xff, 0xff, 0xfb, 0x31, 0x55,
	    0x72, 0x1a, 0xef, 0xf0, 0x07, 0x07, 0x77, 0x2a, 0xe8, 0x12, 0x55, 0x51,
	    0x7f, 0x6c, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x07, 0x07, 0x01, 0xff, 0xff,
	    0xb3, 0x13, 0x57, 0x21, 0xbe, 0x07, 0xe0, 0x07, 0x77, 0x2c, 0xa0, 0x25,
	    0x57, 0x26, 0xbf, 0xfe, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x07, 0x07, 0xeb,
	    0x0f, 0x61, 0x24, 0x52, 0x1a, 0x07, 0x07, 0x77, 0x2d, 0x03, 0xfb, 0x12,
	    0x72, 0x22, 0x3a, 0xdf, 0x07, 0x07, 0xf8, 0x77, 0x2f, 0x07, 0x07, 0x05,
	    0xfc, 0xa3, 0x12, 0x1e, 0x42, 0x31, 0xbf, 0x07, 0x07, 0x77, 0x2e, 0xb2,
	    0x0f, 0x17, 0x52, 0x13, 0x9d, 0x07, 0x07, 0x77, 0x2f, 0xe0, 0x07, 0x07,
	    0x05, 0xc9, 0x11, 0x66, 0x21, 0x1c, 0xf0, 0x07, 0x07, 0x77, 0x2f, 0xfb,
	    0x33, 0x66, 0x62, 0x3f, 0x18, 0xbf, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x07,
	    0x81, 0x03, 0xeb, 0x63, 0x16, 0x41, 0x19, 0xce, 0x07, 0xe0, 0x07, 0x77,
	    0x2f, 0xff, 0xc8, 0x16, 0x22, 0x61, 0x3f, 0x3b, 0xef, 0x07, 0x07, 0x77,
	    0x2f, 0x07, 0x07, 0x81, 0x01, 0xfc, 0xa3, 0x12, 0x63, 0x11, 0x9c, 0x07,
	    0xe0, 0x07, 0x77, 0x2f, 0xff, 0xff, 0xfe, 0x93, 0x27, 0x1f, 0x44, 0x20,
	    0x8c, 0x07, 0x07, 0x77, 0x2f, 0x07, 0xc0, 0x07, 0x01, 0xb6, 0x12, 0x26,
	    0x31, 0x3a, 0xcf, 0xf8, 0x07, 0x07, 0x77, 0x2f, 0x01, 0xfa, 0x21, 0x54,
	    0x1f, 0x57, 0x08, 0xbf, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x80, 0x07, 0xff,
	    0xea, 0x31, 0x25, 0x62, 0x13, 0xbe, 0xf8, 0x07, 0x07, 0x77, 0x2f, 0x02,
	    0xfe, 0xb6, 0x22, 0x0f, 0x55, 0x52, 0x29, 0xcf, 0x07, 0x07, 0x77, 0x2f,
	    0xc0, 0x07, 0x06, 0xeb, 0x91, 0x27, 0x66, 0x11, 0x9c, 0xf8, 0x07, 0x07,
	    0x77, 0x2f, 0x04, 0xfc, 0xa2, 0x22, 0x1f, 0x54, 0x63, 0x3b, 0x07, 0x07,
	    0x77, 0x2f, 0x07, 0x81, 0x06, 0xa2, 0x16, 0x72, 0x22, 0x3a, 0xce, 0x07,
	    0xf0, 0x07, 0x77, 0x2f, 0x05, 0xfa, 0x11, 0x76, 0x66, 0x3f, 0x30, 0x1c,
	    0x07, 0x07, 0x77, 0x2f, 0x07, 0x04, 0x03, 0xb3, 0x13, 0x63, 0x32, 0x11,
	    0xbe, 0x07, 0x07, 0xe0, 0x77, 0x2f, 0x07, 0xc3, 0x13, 0x36, 0x62, 0x60,
	    0x7e, 0x9e, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x02, 0xc6, 0x03, 0x03, 0x33,
	    0x36, 0x30, 0x9e, 0xef, 0x07, 0x07, 0xe0, 0x77, 0x2f, 0x07, 0xff, 0xa1,
	    0x33, 0x77, 0x24, 0x3e, 0x21, 0xae, 0x07, 0x07, 0x77, 0x2f, 0x07, 0xff,
	    0x00, 0xff, 0xca, 0x11, 0x45, 0x63, 0x31, 0x1b, 0xef, 0xf8, 0x07, 0x07,
	    0x77, 0x2f, 0x07, 0xff, 0xff, 0xfc, 0x03, 0x30, 0x36, 0x42, 0x52, 0x13,
	    0xad, 0x07, 0x07, 0xe0, 0x77, 0x2f, 0x06, 0xfe, 0xca, 0x11, 0x57, 0x55,
	    0x1f, 0x13, 0x18, 0xef, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x80, 0x02, 0xeb,
	    0x31, 0x67, 0x74, 0x61, 0x03, 0xbd, 0x7c, 0xef, 0x07, 0x07, 0x77, 0x2f,
	    0x04, 0xcb, 0x11, 0x07, 0x65, 0x22, 0x52, 0x33, 0xbf, 0x07, 0x07, 0x77,
	    0xe0, 0x2f, 0x07, 0x04, 0xca, 0x33, 0x26, 0x65, 0x61, 0x1f, 0x13, 0xbc,
	    0xef, 0x07, 0x07, 0x77, 0x2f, 0x01, 0x00, 0xfe, 0xca, 0x30, 0x22, 0x26,
	    0x62, 0x26, 0xac, 0xfc, 0x07, 0x07, 0x77, 0x2f, 0x07, 0x06, 0xca, 0x31,
	    0x03, 0x36, 0x66, 0x22, 0x16, 0xac, 0xef, 0x07, 0x07, 0xc0, 0x77, 0x2f,
	    0xff, 0xee, 0xb9, 0x32, 0x26, 0x24, 0x1f, 0x62, 0x13, 0xac, 0x07, 0x07,
	    0x77, 0x2f, 0x07, 0x80, 0x07, 0xfd, 0xb8, 0x11, 0x24, 0x55, 0x22, 0x22,
	    0x3c, 0x9b, 0xcf, 0x07, 0x07, 0x77, 0x2e, 0xfc, 0xb9, 0x01, 0x61, 0x22,
	    0x65, 0x42, 0x13, 0xab, 0xef, 0x07, 0xf8, 0x07, 0x77, 0x2f, 0x07, 0x07,
	    0xff, 0xfd, 0xb9, 0x00, 0x31, 0x25, 0x77, 0x56, 0x23, 0x99, 0xcc, 0xef,
	    0xf0, 0x07, 0x07, 0x77, 0x2a, 0xfe, 0xcb, 0x91, 0x12, 0x03, 0x57, 0x72,
	    0x26, 0x13, 0x9b, 0xef, 0x07, 0x07, 0xf8, 0x77, 0x2f, 0x07, 0x07, 0x01,
	    0xfe, 0xba, 0x61, 0x01, 0x22, 0x26, 0x62, 0x33, 0x39, 0xab, 0xce, 0x07,
	    0xc0, 0x07, 0x77, 0xff, 0xff, 0xfe, 0xba, 0x62, 0x25, 0x03, 0x42, 0x25,
	    0x42, 0x11, 0xab, 0xef, 0x07, 0x07, 0xf8, 0x77, 0x2f, 0x07, 0x07, 0x03,
	    0xfe, 0xba, 0x11, 0x00, 0x36, 0x62, 0x22, 0x23, 0x11, 0x3a, 0xbc, 0xef,
	    0xe0, 0x07, 0x07, 0x76, 0xdb, 0x93, 0x11, 0x25, 0x55, 0x07, 0x26, 0x61,
	    0x01, 0xae, 0xef, 0x07, 0x07, 0x77, 0xf0, 0x2f, 0x07, 0x07, 0x06, 0xca,
	    0x30, 0x16, 0x66, 0x01, 0x26, 0x66, 0x21, 0x11, 0x9a, 0xbc, 0xef, 0x07,
	    0xc0, 0x07, 0x72, 0xcb, 0xa8, 0x11, 0x13, 0x66, 0x22, 0x0f, 0x55, 0x31,
	    0x08, 0xbe, 0x07, 0x07, 0x77, 0x2f, 0xe0, 0x07, 0x07, 0x07, 0xff, 0xff,
	    0xeb, 0x93, 0x11, 0x00, 0x55, 0x52, 0x22, 0x22, 0x11, 0x33, 0x9a, 0xbc,
	    0x30, 0xee, 0xef, 0x07, 0x05, 0xed, 0xbb, 0xa9, 0x42, 0x00, 0x11, 0x26,
	    0x66, 0x22, 0x67, 0x21, 0x3a, 0xce, 0xff, 0x27, 0x07, 0x77, 0x2f, 0x07,
	    0x07, 0x07, 0x02, 0x00, 0xec, 0xa7, 0x22, 0x25, 0x54, 0x44, 0x33, 0x33,
	    0x02, 0x11, 0x13, 0x88, 0xab, 0xdd, 0xdd, 0x07, 0xff, 0x00, 0xfd, 0xdd,
	    0xdb, 0xa8, 0x88, 0x30, 0x22, 0x22, 0x01, 0x57, 0x46, 0x22, 0x63, 0x11,
	    0x9b, 0xde, 0x3f, 0xfe, 0xbf, 0x77, 0x2f, 0x07, 0x07, 0x07, 0x05, 0xda,
	    0x00, 0x83, 0x11, 0x13, 0x55, 0x55, 0x55, 0x55, 0x22, 0x00, 0x22, 0x22,
	    0x64, 0x99, 0xaa, 0xab, 0xbb, 0xbb, 0x44, 0xbb, 0xe9, 0xaa, 0xa7, 0x42,
	    0x81, 0x26, 0x55, 0x00, 0x75, 0x52, 0x21, 0x11, 0x88, 0xbd, 0xff, 0xff,
	    0x7f, 0xff, 0xe9, 0xd4, 0xa7, 0x5f, 0x17, 0x07, 0x07, 0xc0, 0x07, 0x04,
	    0xfe, 0xdc, 0xba, 0x93, 0x22, 0x22, 0x00, 0x22, 0x54, 0x66, 0x66, 0x22,
	    0x22, 0x33, 0x31, 0x02, 0x11, 0x33, 0x33, 0x66, 0x66, 0x62, 0x81, 0x22,
	    0x00, 0x22, 0x64, 0x66, 0x66, 0x55, 0x22, 0x22, 0x69, 0x07, 0xab, 0xce,
	    0xff, 0xff, 0xff, 0xe9, 0xd4, 0xa7, 0xfc, 0x5f, 0x17, 0x07, 0x07, 0x07,
	    0x07, 0xee, 0xcb, 0x00, 0xa9, 0x63, 0x11, 0x22, 0x66, 0x66, 0x66, 0x62,
	    0x00, 0x33, 0x33, 0x33, 0x33, 0x33, 0x22, 0x22, 0x22, 0x20, 0x33, 0x36,
	    0x91, 0x63, 0x33, 0x33, 0x11, 0x39, 0x03, 0x9a, 0xbc, 0xee, 0xff, 0xff,
	    0xff, 0xe9, 0xd4, 0xff, 0xa7, 0x5f, 0x17, 0x07, 0x07, 0x07, 0x07, 0x01,
	    0x00, 0xee, 0xcc, 0xba, 0x93, 0x11, 0x01, 0x13, 0x33, 0x01, 0x36, 0x66,
	    0x66, 0x32, 0x66, 0x66, 0x66, 0xe9, 0x00, 0x73, 0x33, 0x11, 0x00, 0x01,
	    0x33, 0xab, 0xce, 0x7f, 0xef, 0x03, 0xdb, 0xb7, 0x6f, 0x27, 0x07, 0x07,
	    0xe0, 0x07, 0x07, 0x07, 0xfe, 0xee, 0xcb, 0xa9, 0x31, 0x00, 0x00, 0x00,
	    0x00, 0x01, 0x11, 0x22, 0x22, 0x22, 0x41, 0x22, 0xb9, 0x00, 0x38, 0x8a,
	    0xbc, 0xee, 0x07, 0xff, 0xbf, 0x77, 0x2f, 0x07, 0x07, 0x07, 0x07, 0x07,
	    0x80, 0x05, 0xee, 0xee, 0xee, 0xee, 0xcc, 0xbb, 0xaa, 0x02, 0x9a, 0xa9,
	    0x9a, 0xaa, 0xbc, 0xcc, 0x99, 0xef, 0xf8, 0x07, 0xbf, 0x77, 0x2f, 0x07,
};


//*****************************************************************************


//*****************************************************************************
//
// Print "Hello World!" to the display on the Intelligent Display Module.
//
//*****************************************************************************
int
main(void)
{
    
    uint32_t ui32SysClock;

    //
    // Run from the PLL at 120 MHz.
    //
    ui32SysClock = SysCtlClockFreqSet((SYSCTL_XTAL_25MHZ |
                                       SYSCTL_OSC_MAIN |
                                       SYSCTL_USE_PLL |
                                       SYSCTL_CFG_VCO_480), 120000000);

    //
    // Configure the device pins.
    //
    PinoutSet();

    //
    // Initialize the display driver.
    //
    Kentec320x240x16_SSD2119Init(ui32SysClock);

    //
    // Initialize the graphics context.
    //
  //  GrContextInit(&sContext, &g_sKentec320x240x16_SSD2119);

    //
    // Draw the application frame.
    //
  //  FrameDraw(&sContext, "hello");

    //
    // Say hello using the Computer Modern 40 point font.
    //
    GrContextFontSet(&sContext_Label, g_psFontCm40);
  /*  GrStringDrawCentered(&sContext, "Hello World!", -1,
                         GrContextDpyWidthGet(&sContext) / 2,
                         ((GrContextDpyHeightGet(&sContext) - 32) / 2) + 24,
                         0);*/
												 
												 
		GrContextInit(&sContext_Label, &g_sKentec320x240x16_SSD2119); //LCD Intialisation
		sRect_Label.i16XMin = 0;
		sRect_Label.i16YMin = 0;											//LCD quardinate
		sRect_Label.i16XMax = 320 - 1;
		sRect_Label.i16YMax = 240; 
		GrContextForegroundSet(&sContext_Label, ClrWhite);			   // Colours
		GrRectFill(&sContext_Label, &sRect_Label);
		GrContextBackgroundSet(&sContext_Label, BACKGROUND_COLOR);
		GrContextForegroundSet(&sContext_Label, BACKGROUND_COLOR);
		GrImageDraw(&sContext_Label, g_pucLogo,  50, 22);			  //Display the logo "Z"


		single_flag=0;
		continuous_flag=1;
		Eneterd_Slave_ID=1;
		Error_Display_Seq=0;

    //
    // Flush any cached drawing operations.
    //
  //  GrFlush(&sContext);

    //
    // We are finished. Hang around doing nothing.
    //
    while(1)
    {
				switch (disp_para_cnt)
			{
				case 0:	
						boot_screen_Load();			   
						if(boot_cnt >= 238) 
						{
							
							//Flag.Data_Update =1;
												
										
						//	Uart1_pc_init();
							disp_para_cnt++;
						}
					
				break;
				
  				case 1:	//Show ERROR measuring screen 
   							Err_measure_Page_Fix_Graphics();
  							disp_para_cnt++;
  				case 2:	//Show updated value on ERROR measuring screen
  							Err_measure_Page_Update();		
				break;

				case 3:	//Show Edge Count screen 
							Edgecount_Page_Fix_Graphics();
							disp_para_cnt++;
				case 4:	//Show updated value on Edge Count screen
							Edgecount_Page_Update();
				break;

				case 5:	//Show ERROR measuring screen 
							Editbutton_Page_Fix_Graphics();
							disp_para_cnt++;
				case 6:	//Show updated value on ERROR measuring screen
							Editbutton_Page_Update();
				break;
//													
//				case 7:	
//							disp_para_cnt=1;	
//				break;
				
			   										  
				default:
				break;
			}
			
			if(disp_para_cnt!=0)
			{
				switch_sense();
			}
    }
}





//*****************************************************************************
///
/// Switch Intialisation
///	I/p: Nothing
/// O/P: noting
/// Remark: Sense the key in diffrent screen
//*****************************************************************************/
 void Switch_init(void)
 {
  SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOE);
	SysCtlPeripheralEnable(SYSCTL_PERIPH_GPION);
	SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOP);   // Enable the GPIO blocks of port pin used.
	
	GPIOPinTypeGPIOInput(Edit_Key_P,Edit_Key);	//Edit key		   //Define PIN as input pin for all rows connected
	GPIOPinTypeGPIOInput(Select_Key_P,Position_Select_Key);	//Select key
	GPIOPinTypeGPIOInput(SC_PULSE_Key_P,SC_PULSE_Key);	// SC pulse select
//	GPIOPinTypeGPIOInput(Switch_S4_P,Switch_S4);	// reset key
	GPIOPinTypeGPIOOutput(GPIO_PORTE_BASE,GPIO_PIN_3);
	GPIOPinTypeGPIOOutput(GPIO_PORTF_BASE,GPIO_PIN_2);	  	  

}

//*****************************************************************************
///
/// Switch Sensing
///	I/p: Nothing
/// O/P: noting
/// Remark: Sense the key in diffrent screen
//*****************************************************************************/
void switch_sense(void)
{
	unsigned long int test1;		
			
		if(GPIOPinRead(Edit_Key_P,Edit_Key)== 0)
		{
			switch_press_S1++;
			if(switch_press_S1>5) 
			{
				disp_para_cnt=5;
				switch_press_S1=0;
				Edit_Enable=1;
			}


			for (test1=0;test1<=5000000;test1++);
			//for (test1=0;test1<=5000000;test1++);
			if(Freeze_position)
			{
				switch_press_S1=0;
				Freeze_position=0;
				Edit_Enable=0;
				disp_para_cnt=1;
				Meter_Place.Slave_ID_flash=	Eneterd_Slave_ID;
						
				Meter_Place.Slave_ID[0]=Eneterd_Slave_ID%10;
				Meter_Place.Slave_ID[1]=Eneterd_Slave_ID/10;
						
				Meter_Place.Slave_ID[0]=Meter_Place.Slave_ID[0]+Meter_Place.Slave_ID[1];
				Meter_Place.Slave_ID[1]=Meter_Place.Slave_ID[0]-Meter_Place.Slave_ID[1];
				Meter_Place.Slave_ID[0]=Meter_Place.Slave_ID[0]-Meter_Place.Slave_ID[1];
						
				Meter_Place.Slave_ID[0]=Meter_Place.Slave_ID[0]+0x30;
				Meter_Place.Slave_ID[1]=Meter_Place.Slave_ID[1]+0x30;
						
		//		Data_write();
						
			}			
			
		}
		
		if(GPIOPinRead(Select_Key_P,Position_Select_Key)== 0)
		{
				
			if(Edit_Enable)
			{
				Eneterd_Slave_ID++;
				if(Eneterd_Slave_ID>40)Eneterd_Slave_ID=1;
				for (test1=0;test1<=5000000;test1++);
				Freeze_position=1;
			
			}
		
		}
			
/*******************Selection between SC and Pulse switch******************************/	
			
		if((GPIOPinRead(SC_PULSE_Key_P,SC_PULSE_Key)== 1)&&(Switch_debounce_flag))
		{
			Switch_debounce_flag=0;	
			for (test1=0;test1<=500000;test1++);
				
		}
			
		if((GPIOPinRead(SC_PULSE_Key_P,SC_PULSE_Key)== 0)&&(Switch_debounce_flag==0))
		{
			for (test1=0;test1<=5000000;test1++);
			Switch_debounce_flag=1;

			SC_PULSE_Selection=~SC_PULSE_Selection;

			

			if(SC_PULSE_Selection==0xFF)
			{
				GPIOPinWrite(GPIO_PORTQ_BASE , GPIO_PIN_4 ,GPIO_PIN_4);		// For Relay ON-OFF
			}
			else
			{	
				GPIOPinWrite(GPIO_PORTQ_BASE , GPIO_PIN_4 ,0);    	 
			}		    
		

     /***************************************************************************************/
		if(GPIOPinRead(Reset_Key_P,Reset_Key)== 0)
		{
			for (test1=0;test1<=5000000;test1++);
			reset_flag=1;
			reset_count++;
			reset_status_flag=2;
							
		}	 
	}
}


/*****************************************************************************
///
/// External pulse sensing Intialisation
///	I/p: Nothing
/// O/P: noting
/// Remark: Sense the key in diffrent screen
*****************************************************************************/
/*void External_pulse_init(void)
 {
  	SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOE);   // Enable the GPIO blocks of port pin used.
	GPIOPinTypeGPIOInput(GPIO_PORTE_BASE,GPIO_PIN_4);	// external interrupt pin
 }*/


 

